# Import data
aggregatedData <- read.table("raw_data.csv", header=TRUE, sep = ";")
aggregatedData <- aggregatedData[2:9]


# ==================================================
# VISTYPE STZ
# ==================================================

TimingsSTZ <- aggregatedData[aggregatedData[6]=="STZ",1:8]

# --- Timing Histograms for all Tasks of vistype STZ with same setting ---
pdf("timingHistograms-stz1.pdf",width=8.3,height=11.7) 
par(mfrow=c(6,2),mar=c(5,5,1,2)) 
for (taskNr in 1:12) {
	hist(TimingsSTZ[TimingsSTZ[2]==taskNr,3], seq(0,100,5), main="", xlab=paste("Task ", taskNr), ylab="Frequency")
	rug(TimingsSTZ[TimingsSTZ[2]==taskNr,3])
}
dev.off()

# # --- Timing Histograms for all Tasks of Interface STZ ---
pdf("timingHistograms-stz2.pdf",width=8.3,height=11.7) 
par(mfrow=c(6,2),mar=c(5,5,1,2)) 
for (taskNr in 1:12) {
	hist(TimingsSTZ[TimingsSTZ[2]==taskNr,3], main="", xlab=paste("Task ", taskNr), ylab="Frequency")
	rug(TimingsSTZ[TimingsSTZ[2]==taskNr,3])
}
dev.off()

 # --- Boxplots for Timings of Interface A ---
 pdf("timingBoxplots-stz.pdf",width=7,height=11) 
 boxplot(TimingsSTZ[TimingsSTZ[2]=="1",3], TimingsSTZ[TimingsSTZ[2]=="2",3], TimingsSTZ[TimingsSTZ[2]=="3",3], TimingsSTZ[TimingsSTZ[2]=="4",3],
		 TimingsSTZ[TimingsSTZ[2]=="5",3], TimingsSTZ[TimingsSTZ[2]=="6",3], TimingsSTZ[TimingsSTZ[2]=="7",3], TimingsSTZ[TimingsSTZ[2]=="8",3],
		 TimingsSTZ[TimingsSTZ[2]=="9",3], TimingsSTZ[TimingsSTZ[2]=="10",3], TimingsSTZ[TimingsSTZ[2]=="11",3], TimingsSTZ[TimingsSTZ[2]=="12",3], 
		 ylab="time (s)", ylab="Task", names=c(1:12))
 dev.off()

# --- Summary Statistics ---
sumstats_STZ <- data.frame(Task=1, MIN=min(TimingsSTZ[TimingsSTZ[2]==1,3]), Q1=quantile(TimingsSTZ[TimingsSTZ[2]==1,3],0.25), MEDIAN=median(TimingsSTZ[TimingsSTZ[2]==1,3]), MEAN=mean(TimingsSTZ[TimingsSTZ[2]==1,3]), Q3=quantile(TimingsSTZ[TimingsSTZ[2]==1,3],0.75), MAX=max(TimingsSTZ[TimingsSTZ[2]==1,3]), SD=sd(TimingsSTZ[TimingsSTZ[2]==1,3]))
for (taskNr in 2:12) {
	sumstats_STZ <- rbind(sumstats_STZ, c(taskNr,min(TimingsSTZ[TimingsSTZ[2]==taskNr,3]),quantile(TimingsSTZ[TimingsSTZ[2]==taskNr,3],0.25),median(TimingsSTZ[TimingsSTZ[2]==taskNr,3]),mean(TimingsSTZ[TimingsSTZ[2]==taskNr,3]),quantile(TimingsSTZ[TimingsSTZ[2]==taskNr,3],0.75),max(TimingsSTZ[TimingsSTZ[2]==taskNr,3]),sd(TimingsSTZ[TimingsSTZ[2]==taskNr,3])))
}
write.csv(sumstats_STZ,file="sumstats_STZ.csv")

# # --- Normal Distribution Tests --
# shapirowilk_STZ <- data.frame(Task=1,SW=shapiro.test(TimingsA[TimingsA[2]==1,3])$p.value)
# for (taskNr in 2:12) {
	# sw <- shapiro.test(TimingsA[TimingsA[2]==taskNr,3])$p.value
	# shapirowilk_STZ <- rbind(shapirowilk_STZ, c(taskNr,sw))
# }
# write.csv(shapirowilk_STZ,file="shapirowilk_STZ.csv")

# # --- Log-Normal Distribution Tests --
# shapirowilk_STZ <- data.frame(Task=1,SW=shapiro.test(log(TimingsA[TimingsA[2]==1,3]))$p.value)
# for (taskNr in 2:12) {
	# sw <- shapiro.test(log(TimingsA[TimingsA[2]==taskNr,3]))$p.value
	# shapirowilk_STZ <- rbind(shapirowilk_STZ, c(taskNr,sw))
# }
# write.csv(shapirowilk_STZ,file="shapirowilk_STZ_log.csv")

# # ==================================================
# # INTERFACE KNAVE
# # ==================================================

TimingsKNAVE <- aggregatedData[aggregatedData[6]=="KNAVE",1:8]

# --- Timing Histograms for all Tasks of Interface KNAVE with same setting ---
pdf("timingHistograms-knave1.pdf",width=8.3,height=11.7) 
par(mfrow=c(6,2),mar=c(5,5,1,2)) 
for (taskNr in 1:12) {
	hist(TimingsKNAVE[TimingsKNAVE[2]==taskNr,3], seq(0,100,5), main="", xlab=paste("Task ", taskNr), ylab="Frequency")
	rug(TimingsKNAVE[TimingsKNAVE[2]==taskNr,3])
}
dev.off()

# --- Timing Histograms for all Tasks of Interface KNAVE ---
pdf("timingHistograms-knave2.pdf",width=8.3,height=11.7) 
par(mfrow=c(6,2),mar=c(5,5,1,2)) 
for (taskNr in 1:12) {
	hist(TimingsKNAVE[TimingsKNAVE[2]==taskNr,3], main="", xlab=paste("Task ", taskNr), ylab="Frequency")
	rug(TimingsKNAVE[TimingsKNAVE[2]==taskNr,3])
}
dev.off()

 # --- Boxplots for Timings of Interface KNAVE ---
 pdf("timingBoxplots-knave.pdf",width=7,height=11) 
 boxplot(TimingsKNAVE[TimingsKNAVE[2]=="1",3], TimingsKNAVE[TimingsKNAVE[2]=="2",3], TimingsKNAVE[TimingsKNAVE[2]=="3",3], TimingsKNAVE[TimingsKNAVE[2]=="4",3],
		 TimingsKNAVE[TimingsKNAVE[2]=="5",3], TimingsKNAVE[TimingsKNAVE[2]=="6",3], TimingsKNAVE[TimingsKNAVE[2]=="7",3], TimingsKNAVE[TimingsKNAVE[2]=="8",3],
		 TimingsKNAVE[TimingsKNAVE[2]=="9",3], TimingsKNAVE[TimingsKNAVE[2]=="10",3], TimingsKNAVE[TimingsKNAVE[2]=="11",3], TimingsKNAVE[TimingsKNAVE[2]=="12",3], 

		 ylab="time (s)", ylab="Task", names=c(1:12))
 dev.off()

# # --- Summary Statistics ---
 sumstats_KNAVE <- data.frame(Task=1, MIN=min(TimingsKNAVE[TimingsKNAVE[2]==1,3]), Q1=quantile(TimingsKNAVE[TimingsKNAVE[2]==1,3],0.25), MEDIAN=median(TimingsKNAVE[TimingsKNAVE[2]==1,3]), MEAN=mean(TimingsKNAVE[TimingsKNAVE[2]==1,3]), Q3=quantile(TimingsKNAVE[TimingsKNAVE[2]==1,3],0.75), MAX=max(TimingsKNAVE[TimingsKNAVE[2]==1,3]), SD=sd(TimingsKNAVE[TimingsKNAVE[2]==1,3]))
 for (taskNr in 2:12) {
	 sumstats_KNAVE <- rbind(sumstats_KNAVE, c(taskNr,min(TimingsKNAVE[TimingsKNAVE[2]==taskNr,3]),quantile(TimingsKNAVE[TimingsKNAVE[2]==taskNr,3],0.25),median(TimingsKNAVE[TimingsKNAVE[2]==taskNr,3]),mean(TimingsKNAVE[TimingsKNAVE[2]==taskNr,3]),quantile(TimingsKNAVE[TimingsKNAVE[2]==taskNr,3],0.75),max(TimingsKNAVE[TimingsKNAVE[2]==taskNr,3]),sd(TimingsKNAVE[TimingsKNAVE[2]==taskNr,3])))
 }
 write.csv(sumstats_KNAVE,file="sumstats_KNAVE.csv")


# # ==================================================
# # Two-way analysis of variance (ANOVA) - Interaction between dataset and vistype
# # ==================================================
# aov.T = aov(duration_s ~as.factor(dataset)*as.factor(visType), aggregatedData)
# summary(aov.T)
# print(model.tables(aov.T,"means"),digits=3)


# # ==================================================
# # Two-way analysis of variance (ANOVA) - Interaction between vis-order and vistype
# # ==================================================
# aov.T = aov(duration_s ~as.factor(order)*as.factor(visType), aggregatedData)
# summary(aov.T)
# print(model.tables(aov.T,"means"),digits=3)

# # ==================================================
# # Two-way analysis of variance (ANOVA) - Interaction between inputtype and vistype
# # ==================================================
# aov.T = aov(duration_s ~as.factor(inputType)*as.factor(visType), aggregatedData)
# summary(aov.T)
# print(model.tables(aov.T,"means"),digits=3)

# # ==================================================
# # RM analysis of variance (ANOVA) - Influence of vistype
# # ==================================================

# aov <- aov(duration_s ~ as.factor(visType) + Error(factor(participantId)/factor(visType)), aggregatedData)
# summary(aov)

# ==================================================
# Split up VisType
# ==================================================

#TimingsSTZ <- aggregatedData[aggregatedData[6]=="STZ" ,1:8]

#TimingsKNAVE <- aggregatedData[aggregatedData[6]=="KNAVE",1:8]

# # ==================================================
# # Histograms 
# # ==================================================

# --- Timing Histograms for all Tasks of Interface STZ, (same settings)---
pdf("timingHistograms_together/timingHistograms-stz-same.pdf",width=8.3,height=11.7) 
par(mfrow=c(6,2),mar=c(5,5,1,2)) 
for (taskNr in 1:12) {
	hist(TimingsSTZ[TimingsSTZ[2]==taskNr,3], seq(0,100,5), main="", xlab=paste("Task ", taskNr), ylab="Frequency")
	rug(TimingsSTZ[TimingsSTZ[2]==taskNr,3])
}
dev.off()

# --- Timing Histograms for all Tasks of Interface STZ,
pdf("timingHistograms_together/timingHistograms-stz.pdf",width=8.3,height=11.7) 
par(mfrow=c(6,2),mar=c(5,5,1,2)) 
for (taskNr in 1:12) {
	hist(TimingsSTZ[TimingsSTZ[2]==taskNr,3], main="", xlab=paste("Task ", taskNr), ylab="Frequency")
	rug(TimingsSTZ[TimingsSTZ[2]==taskNr,3])
}
dev.off()

# --- Timing Histograms for all Tasks of Interface KNAVE (same settings)
pdf("timingHistograms_together/timingHistograms-knave-same.pdf",width=8.3,height=11.7) 
par(mfrow=c(6,2),mar=c(5,5,1,2)) 
for (taskNr in 1:12) {
	hist(TimingsKNAVE[TimingsKNAVE[2]==taskNr,3], seq(0,100,5), main="", xlab=paste("Task ", taskNr), ylab="Frequency")
	rug(TimingsKNAVE[TimingsKNAVE[2]==taskNr,3])
}
dev.off()

# --- Timing Histograms for all Tasks of Interface KNAVE
pdf("timingHistograms_together/timingHistograms-knave.pdf",width=8.3,height=11.7) 
par(mfrow=c(6,2),mar=c(5,5,1,2)) 
for (taskNr in 1:12) {
	hist(TimingsKNAVE[TimingsKNAVE[2]==taskNr,3], main="", xlab=paste("Task ", taskNr), ylab="Frequency")
	rug(TimingsKNAVE[TimingsKNAVE[2]==taskNr,3])
}
dev.off()



# # ==================================================
# # Histograms - Log times
# # ==================================================

# --- Timing Histograms for all Tasks of Interface STZ, Order 1 (same settings)---
pdf("timingHistograms_together/log_timingHistograms-stz-same.pdf",width=8.3,height=11.7) 
par(mfrow=c(6,2),mar=c(5,5,1,2)) 
for (taskNr in 1:12) {
	hist(log(TimingsSTZ[TimingsSTZ[2]==taskNr,3]), seq(0,5,0.5), main="", xlab=paste("Task ", taskNr), ylab="Frequency")
	rug(log(TimingsSTZ[TimingsSTZ[2]==taskNr,3]))
}
dev.off()

# --- Timing Histograms for all Tasks of Interface STZ, Order 1 ---
pdf("timingHistograms_together/log_timingHistograms-stz.pdf",width=8.3,height=11.7) 
par(mfrow=c(6,2),mar=c(5,5,1,2)) 
for (taskNr in 1:12) {
	hist(log(TimingsSTZ[TimingsSTZ[2]==taskNr,3]), main="", xlab=paste("Task ", taskNr), ylab="Frequency")
	rug(log(TimingsSTZ[TimingsSTZ[2]==taskNr,3]))
}
dev.off()

# --- Timing Histograms for all Tasks of Interface KNAVE, Order 1 (same settings)
pdf("timingHistograms_together/log_timingHistograms-knave-same.pdf",width=8.3,height=11.7) 
par(mfrow=c(6,2),mar=c(5,5,1,2)) 
for (taskNr in 1:12) {
	hist(log(TimingsKNAVE[TimingsKNAVE[2]==taskNr,3]), seq(0,5,0.5), main="", xlab=paste("Task ", taskNr), ylab="Frequency")
	rug(log(TimingsKNAVE[TimingsKNAVE[2]==taskNr,3]))
}
dev.off()

# --- Timing Histograms for all Tasks of Interface KNAVE, Order 1 ---
pdf("timingHistograms_together/log_timingHistograms-knave.pdf",width=8.3,height=11.7) 
par(mfrow=c(6,2),mar=c(5,5,1,2)) 
for (taskNr in 1:12) {
	hist(log(TimingsKNAVE[TimingsKNAVE[2]==taskNr,3]), main="", xlab=paste("Task ", taskNr), ylab="Frequency")
	rug(log(TimingsKNAVE[TimingsKNAVE[2]==taskNr,3]))
}
dev.off()



# ==================================================
# COMPARISON BOXPLOT - OVERALL
# ==================================================
pdf("timingBoxplots-comparison_overall.pdf",width=11.7,height=7) 
boxplot(duration_s ~ taskType, data = TimingsSTZ, at = 1:12 - 0.2, boxwex = 0.15, col = colors()[c(50)], names=c("","","","","","","","","","","",""), main="Task completion times (Overall)", xlab="Tasks", ylab="time (s)", axes = FALSE, ylim=c(0,90))
boxplot(duration_s ~ taskType, data = TimingsKNAVE, at = 1:12, boxwex = 0.15, col = colors()[c(79)], add = TRUE)

legend(0.2, 75, c("STZ", "KNAVE"),
       fill = colors()[c(50,79)], bty="n")
dev.off()



# ==================================================
# NORMAL DISTRIBUTION - STZ
# ==================================================

 # --- Normal Distribution Tests --
 shapirowilk_STZ <- data.frame(Task=1,SW=shapiro.test(TimingsSTZ[TimingsSTZ[2]==1,3])$p.value)
 for (taskNr in 2:12) {
	 sw <- shapiro.test(TimingsSTZ[TimingsSTZ[2]==taskNr,3])$p.value
	 shapirowilk_STZ <- rbind(shapirowilk_STZ, c(taskNr,sw))
 }
 write.csv(shapirowilk_STZ,file="shapirowilk_STZ.csv")
 
  # --- Log-Normal Distribution Tests --
 shapirowilk_STZ <- data.frame(Task=1,SW=shapiro.test(log(TimingsSTZ[TimingsSTZ[2]==1,3]))$p.value)
 for (taskNr in 2:12) {
	 sw <- shapiro.test(log(TimingsSTZ[TimingsSTZ[2]==taskNr,3]))$p.value
	 shapirowilk_STZ <- rbind(shapirowilk_STZ, c(taskNr,sw))
 }
 write.csv(shapirowilk_STZ,file="shapirowilk_STZ_log.csv")


# ==================================================
# NORMAL DISTRIBUTION - KNAVE
# ==================================================

 # --- Normal Distribution Tests - Round 1 --
 shapirowilk_KNAVE <- data.frame(Task=1,SW=shapiro.test(TimingsKNAVE[TimingsKNAVE[2]==1,3])$p.value)
 for (taskNr in 2:12) {
	 sw <- shapiro.test(TimingsKNAVE[TimingsKNAVE[2]==taskNr,3])$p.value
	 shapirowilk_KNAVE <- rbind(shapirowilk_KNAVE, c(taskNr,sw))
 }
 write.csv(shapirowilk_KNAVE,file="shapirowilk_KNAVE.csv")
 
  # --- Log-Normal Distribution Tests Round 1 --
 shapirowilk_KNAVE <- data.frame(Task=1,SW=shapiro.test(log(TimingsKNAVE[TimingsKNAVE[2]==1,3]))$p.value)
 for (taskNr in 2:12) {
	 sw <- shapiro.test(log(TimingsKNAVE[TimingsKNAVE[2]==taskNr,3]))$p.value
	 shapirowilk_KNAVE <- rbind(shapirowilk_KNAVE, c(taskNr,sw))
 }
 write.csv(shapirowilk_KNAVE,file="shapirowilk_KNAVE_log.csv")


# # ==================================================
# TESTING FOR EQUAL VARIANCE (F-TEST) - 
# ==================================================

 equal_variance <- data.frame(Task=1,SW=var.test(log(TimingsSTZ[TimingsSTZ[2]== "1", "duration_s"]), log(TimingsKNAVE[TimingsKNAVE[2]== "1", "duration_s"]))$p.value)
 for (taskNr in 2:12) {
 	sw <-var.test(log(TimingsSTZ[TimingsSTZ[2]== taskNr, "duration_s"]), log(TimingsKNAVE[TimingsKNAVE[2]== taskNr, "duration_s"]))$p.value
 	equal_variance <- rbind(equal_variance, c(taskNr,sw))
 }
 write.csv(equal_variance,file="log_equal_variance.csv")



# ==================================================
# T-TEST SINGLE TASKS
# ==================================================

t_test <- data.frame(Task=1,SW=t.test(log(TimingsSTZ[TimingsSTZ[2]== "1", "duration_s"]), log(TimingsKNAVE[TimingsKNAVE[2]== "1", "duration_s"]), paired = T )$p.value)
 for (taskNr in 2:12) {
 	t.test(log(TimingsSTZ[TimingsSTZ[2]== taskNr, "duration_s"]), log(TimingsKNAVE[TimingsKNAVE[2]== taskNr, "duration_s"]), paired = T)
 	sw <-t.test(log(TimingsSTZ[TimingsSTZ[2]== taskNr, "duration_s"]), log(TimingsKNAVE[TimingsKNAVE[2]== taskNr, "duration_s"]), paired = T)$p.value
 	t_test <- rbind(t_test, c(taskNr,sw))
 }
 write.csv(t_test,file="t_test_log.csv")
 
# ==================================================
# FRIEDMAN TEST - Tasktype 1 & 2
# ==================================================

#wilcox.test(GroupA, GroupB, paired=T)


# # ==================================================
# # AMOUNT OF TASKS FOR EACH DATASET
# # ==================================================
# amountDataset1 <- length(aggregatedData[aggregatedData[6]==1,6])
# amountDataset2 <- length(aggregatedData[aggregatedData[6]==2,6])

# pdf("tasks-per-dataset_histogram.pdf",width=4,height=7) 
# # mar: bottom, left, top, right
# par(mar=c(12,5,3,2))
# hist(aggregatedData[,6],seq(0.5,3.5,1), xlab="Dataset", ylab="Amount of tasks", main="Tasks per Dataset", border="white", col = colors()[c(131,655)])
# mtext(paste("Dataset 1: ", amountDataset1),side=1,line=6,cex=1.1)
# mtext(paste("Dataset 2: ", amountDataset2),side=1,line=7,cex=1.1)
# dev.off()

# # ==================================================
# # Boxplot Task Completion Times by dataset - ALL in single plot
# # ==================================================
# library(fields)
# pdf("timingBoxplots-tasks-datasets_all.pdf",width=11.7,height=7)
 
# # bplot(duration_ms ~ taskType*dataset , data = aggregatedData, at=myAt,  main="Task completion times", xlab="Tasks", ylab="time (s)",  col = colors()[c(131,655)], names=c("1","","2","","3","","4","","5","","6","","7","","8","","9","","10","","11","","12",""))
# bplot(duration_ms ~ taskType , data = subset(aggregatedData,dataset =="1"),boxwex = 0.15, at = 1:12 - 0.2,names=c("","","","","","","","","","","",""), main="Task completion times", xlab="Tasks", ylab="time (s)",  col = colors()[c(131)], ylim=c(0,90), axes = FALSE)
# bplot(duration_ms ~ taskType, data = subset(aggregatedData,dataset =="2"),boxwex = 0.15, at = 1:12, col = colors()[c(655)], add = TRUE)
# legend("topleft", c("Dataset 1", "Dataset 2"),
       # fill = colors()[c(131,655)], bty="n", cex=0.8)
# dev.off()
# # ==================================================
# # Boxplot Task Completion Times per Dataset - on top of each other
# # ==================================================
# pdf("timingBoxplots-tasks-datasets.pdf",width=10,height=) 
# par(mfrow=c(4,3),mar=c(5,5,2,2)) 
# for (taskNr in 1:12) {
	# boxplot(duration_ms ~ dataset*visType, data = aggregatedData, subset = taskType ==taskNr, main=paste("Task",taskNr), xlab="Dataset", ylab="time (s)", col = colors()[c(131,655)], boxwex=0.5)
	# #boxplot(time_s ~ dataset, data = Timings, subset = task==taskNr, main=paste("Task",taskNr), xlab="Dataset", ylab="time (s)", col = colors()[c(131,655,640)], boxwex=0.5, ylim=c(min(Timings[,4]), max(Timings[,4])))
	# legend("topright", c("Dataset 1", "Dataset 2"),
       # fill = colors()[c(131,655)], bty="n", cex=0.8)
# }
# dev.off()

# # ==================================================
# # One-way analysis of variance (ANOVA)
# # ==================================================
# results <- character(0)
# for (taskNr in 1:12) {
	# timingsTask <- aggregatedData[aggregatedData[3]==taskNr, 1:6]
	# aov.T = aov(duration_ms ~as.factor(dataset),timingsTask)
	# results <- c(results, summary(aov.T))
	# #print(model.tables(aov.T,"means"),digits=3)
# }



# # # ==================================================
# # # Two-way analysis of variance (ANOVA) - Interaction between subject and interface
# # # ==================================================
# # aov.T = aov(time_s~subject*interface,Timings)
# # summary(aov.T)
# # print(model.tables(aov.T,"means"),digits=3)

# # # ==================================================
# # # Two-way analysis of variance (ANOVA) - Interaction between task and interface
# # # ==================================================
# # aov.T = aov(time_s~as.factor(task)*as.factor(interface),Timings)
# # summary(aov.T)
# # print(model.tables(aov.T,"means"),digits=3)

# # # ==================================================
# # # Two-way analysis of variance (ANOVA) - Interaction between task and dataset
# # # ==================================================
# # aov.T = aov(time_s~task*dataset,Timings)
# # summary(aov.T)
# # print(model.tables(aov.T,"means"),digits=3)

# # # ==================================================
# # # Remove Task 12 from Timings
# # # ==================================================
# # TimingsWithoutTwelve <-  Timings[Timings[3]!=12, 1:6]

# # # ==================================================
# # # Two-way analysis of variance (ANOVA) - Interaction between dataset and interface without Task 12
# # # ==================================================
# # aov.T = aov(time_s~dataset*interface,TimingsWithoutTwelve)
# # summary(aov.T)
# # print(model.tables(aov.T,"means"),digits=3)

# # # ==================================================
# # # Two-way analysis of variance (ANOVA) - Interaction between task and interface without Task 12
# # # ==================================================
# # aov.T = aov(time_s~task*interface,TimingsWithoutTwelve)
# # summary(aov.T)
# # print(model.tables(aov.T,"means"),digits=3)

# # # ==================================================
# # # Two-way analysis of variance (ANOVA) - Interaction between task and dataset without Task 12
# # # ==================================================
# # aov.T = aov(time_s~task*dataset,TimingsWithoutTwelve)
# # summary(aov.T)
# # print(model.tables(aov.T,"means"),digits=3)



# # # ==================================================
# # # Histogram Lattice of completion times for Task 4
# # # ==================================================
# # pdf("timeHistogram_tasks-datasets_lattice-task4.pdf",width=7,height=20) 
# # par(mar=c(5,5,1,2)) 
# # library(lattice)

# # ## Set background color of strips to grayscales: 
# # strip.background <- trellis.par.get("strip.background") 
# # trellis.par.set(strip.background = list(col = grey(7:1/8)))
# # strip.border <- trellis.par.get("strip.border") 
# # trellis.par.set(strip.border = list(col = grey(7:1/8)))
# # axis.line <- trellis.par.get("axis.line") 
# # trellis.par.set(axis.line = list(col = grey(7:1/8)))

# # histogram(~time_s | dataset * task, data=Timings, type="count", layout = c(3,14), as.table=TRUE, col = c("black"), border = "white", xlab="Task set completion time (s)", ylab="Count")

# # dev.off()

# # # ==================================================
# # # Test for normal distribution (Task 4)
# # # ==================================================
# # shapiro.test(Timings[Timings[3]==4 & Timings[6]==1, 4])$p.value

# # # ==================================================
# # # Kruskal-Wallis test (non-parametric)
# # # ==================================================
# # results <- character(0)
# # for (taskNr in 1:14) {
	# # timingsTask <- Timings[Timings[3]==taskNr, 1:6]
	# # kruskal.T = kruskal.test(time_s~dataset,timingsTask)$p.value
	# # results <- c(results, kruskal.T)
# # }