# Import data
aggregatedData <- read.table("raw_data.csv", header=TRUE, sep = ";")
aggregatedData <- aggregatedData[2:9]


# ==================================================
# VISTYPE STZ --- Summary Statistics ---
# ==================================================

TimingsSTZ <- aggregatedData[aggregatedData[6]=="STZ",1:8]


sumstats_STZ <- data.frame(Task=1, MIN=min(TimingsSTZ[TimingsSTZ[2]==1,3]), Q1=quantile(TimingsSTZ[TimingsSTZ[2]==1,3],0.25), MEDIAN=median(TimingsSTZ[TimingsSTZ[2]==1,3]), MEAN=mean(TimingsSTZ[TimingsSTZ[2]==1,3]), Q3=quantile(TimingsSTZ[TimingsSTZ[2]==1,3],0.75), MAX=max(TimingsSTZ[TimingsSTZ[2]==1,3]), SD=sd(TimingsSTZ[TimingsSTZ[2]==1,3]))
for (taskNr in 2:12) {
	sumstats_STZ <- rbind(sumstats_STZ, c(taskNr,min(TimingsSTZ[TimingsSTZ[2]==taskNr,3]),quantile(TimingsSTZ[TimingsSTZ[2]==taskNr,3],0.25),median(TimingsSTZ[TimingsSTZ[2]==taskNr,3]),mean(TimingsSTZ[TimingsSTZ[2]==taskNr,3]),quantile(TimingsSTZ[TimingsSTZ[2]==taskNr,3],0.75),max(TimingsSTZ[TimingsSTZ[2]==taskNr,3]),sd(TimingsSTZ[TimingsSTZ[2]==taskNr,3])))
}
write.csv(sumstats_STZ,file="sumstats_STZ.csv")

# ==================================================
# VISTYPE KNAVE --- Summary Statistics ---
# ==================================================

TimingsKNAVE <- aggregatedData[aggregatedData[6]=="KNAVE",1:8]

# # --- Summary Statistics ---
 sumstats_KNAVE <- data.frame(Task=1, MIN=min(TimingsKNAVE[TimingsKNAVE[2]==1,3]), Q1=quantile(TimingsKNAVE[TimingsKNAVE[2]==1,3],0.25), MEDIAN=median(TimingsKNAVE[TimingsKNAVE[2]==1,3]), MEAN=mean(TimingsKNAVE[TimingsKNAVE[2]==1,3]), Q3=quantile(TimingsKNAVE[TimingsKNAVE[2]==1,3],0.75), MAX=max(TimingsKNAVE[TimingsKNAVE[2]==1,3]), SD=sd(TimingsKNAVE[TimingsKNAVE[2]==1,3]))
 for (taskNr in 2:12) {
	 sumstats_KNAVE <- rbind(sumstats_KNAVE, c(taskNr,min(TimingsKNAVE[TimingsKNAVE[2]==taskNr,3]),quantile(TimingsKNAVE[TimingsKNAVE[2]==taskNr,3],0.25),median(TimingsKNAVE[TimingsKNAVE[2]==taskNr,3]),mean(TimingsKNAVE[TimingsKNAVE[2]==taskNr,3]),quantile(TimingsKNAVE[TimingsKNAVE[2]==taskNr,3],0.75),max(TimingsKNAVE[TimingsKNAVE[2]==taskNr,3]),sd(TimingsKNAVE[TimingsKNAVE[2]==taskNr,3])))
 }
 write.csv(sumstats_KNAVE,file="sumstats_KNAVE.csv")


# ==================================================
# Two-way analysis of variance (ANOVA) - Interaction between dataset and vistype
# ==================================================
aov.T = aov(duration_s ~as.factor(dataset)*as.factor(visType), aggregatedData)
summary(aov.T)
print(model.tables(aov.T,"means"),digits=3)

# ==================================================
# Paired t-test between datasets
# ==================================================

TimingsDataset1 <- aggregatedData[aggregatedData[7]==1,1:8]
TimingsDataset2 <- aggregatedData[aggregatedData[7]==2,1:8]
var.test(log(TimingsDataset2$duration_s), log(TimingsDataset1$duration_s))

shapiro.test(log(TimingsDataset1 $duration_s))
shapiro.test(log(TimingsDataset2 $duration_s))
t.test(log(subset(aggregatedData, dataset==1)$duration_s),log(subset(aggregatedData, dataset==2)$duration_s), paired=T)

# ==================================================
# Two-way analysis of variance (ANOVA) - Interaction between vis-order and vistype
# ==================================================
aov.T = aov(duration_s ~as.factor(order)*as.factor(visType), aggregatedData)
summary(aov.T)
print(model.tables(aov.T,"means"),digits=3)

# ==================================================
# Two-way analysis of variance (ANOVA) - Interaction between inputtype and vistype
# ==================================================
aov.T = aov(duration_s ~as.factor(inputType)*as.factor(visType), aggregatedData)
summary(aov.T)
print(model.tables(aov.T,"means"),digits=3)

# ==================================================
# RM analysis of variance (ANOVA) - Influence of vistype
# ==================================================

aov <- aov(duration_s ~ as.factor(visType) + Error(factor(participantId)/factor(visType)), aggregatedData)
summary(aov)

# ==================================================
# Split up VisType and Order
# ==================================================

TimingsSTZ_Order_1 <- aggregatedData[aggregatedData[6]=="STZ" & aggregatedData[8]=="1",1:8]
TimingsSTZ_Order_2 <- aggregatedData[aggregatedData[6]=="STZ" & aggregatedData[8]=="2",1:8]
TimingsKNAVE_Order_1 <- aggregatedData[aggregatedData[6]=="KNAVE" & aggregatedData[8]=="1",1:8]
TimingsKNAVE_Order_2 <- aggregatedData[aggregatedData[6]=="KNAVE" & aggregatedData[8]=="2",1:8]

# ==================================================
# COMPARISON BOXPLOT - OVERALL
# ==================================================
pdf("timingBoxplots-comparison_overall.pdf",width=11.7,height=7) 
boxplot(duration_s ~ taskType, data = TimingsSTZ, at = 1:12 - 0.2, boxwex = 0.15, col = colors()[c(50)], names=c("","","","","","","","","","","",""), main="Task completion times (Overall)", xlab="Tasks", ylab="time (s)", axes = FALSE, ylim=c(0,90))
boxplot(duration_s ~ taskType, data = TimingsKNAVE, at = 1:12, boxwex = 0.15, col = colors()[c(79)], add = TRUE)

legend(0.2, 75, c("STZ", "KNAVE"),
       fill = colors()[c(50,79)], bty="n")
dev.off()

# ==================================================
# COMPARISON BOXPLOT - DATASET
# ==================================================


pdf("timingBoxplots-comparison_dataset.pdf",width=5,height=7) 
boxplot(log(duration_s) ~ dataset, data = aggregatedData, col = colors()[c(50,79)], main="Task completion times for dataset", xlab="Dataset", ylab="log (time)" )
dev.off()

# ==================================================
# COMPARISON BOXPLOT - ROUNDS
# ==================================================

pdf("timingBoxplots-comparison_order.pdf",width=5,height=7) 
par(mfrow=c(1,2),mar=c(5,5,1,2)) 
boxplot((duration_s) ~ order, data = TimingsSTZ, col = colors()[c(50,79)], main="STZ", xlab="Experiment round", ylab="time (s)", ylim=c(0,65) )
boxplot((duration_s) ~ order, data = TimingsKNAVE, col = colors()[c(50,79)], main="KNAVE", xlab="Experiment round", ylab="time (s)" , ylim=c(0,65) )
dev.off()


# ==================================================
# COMPARISON BOXPLOT - ROUND 1
# ==================================================
pdf("timingBoxplots-comparison_round_1.pdf",width=11.7,height=7) 
boxplot(duration_s ~ taskType, data = TimingsSTZ_Order_1, at = 1:12 - 0.2, boxwex = 0.15, col = colors()[c(50)], names=c("","","","","","","","","","","",""), main="Task completion times (Round 1)", xlab="Tasks", ylab="time (s)", axes = FALSE, ylim=c(0,90))
boxplot(duration_s ~ taskType, data = TimingsKNAVE_Order_1, at = 1:12, boxwex = 0.15, col = colors()[c(79)], add = TRUE)

legend(0.2, 75, c("STZ", "KNAVE"),
       fill = colors()[c(50,79)], bty="n")
dev.off()

# ==================================================
# COMPARISON BOXPLOT - ROUND 2
# ==================================================
pdf("timingBoxplots-comparison_round_2.pdf",width=11.7,height=7) 
boxplot(duration_s ~ taskType, data = TimingsSTZ_Order_2, at = 1:12 - 0.2, boxwex = 0.15, col = colors()[c(50)], names=c("","","","","","","","","","","",""), main="Task completion times (Round 2)", xlab="Tasks", ylab="time (s)", axes = FALSE, ylim=c(0,90))
boxplot(duration_s ~ taskType, data = TimingsKNAVE_Order_2, at = 1:12, boxwex = 0.15, col = colors()[c(79)], add = TRUE)

legend(0.2, 75, c("STZ", "KNAVE"),
       fill = colors()[c(50,79)], bty="n")
dev.off()

# ==================================================
# NORMAL DISTRIBUTION - ROUND 1 STZ
# ==================================================

 # --- Normal Distribution Tests - Round 1 --
 shapirowilk_STZ <- data.frame(Task=1,SW=shapiro.test(TimingsSTZ_Order_1[TimingsSTZ_Order_1[2]==1,3])$p.value)
 for (taskNr in 2:12) {
	 sw <- shapiro.test(TimingsSTZ_Order_1[TimingsSTZ_Order_1[2]==taskNr,3])$p.value
	 shapirowilk_STZ <- rbind(shapirowilk_STZ, c(taskNr,sw))
 }
 write.csv(shapirowilk_STZ,file="shapirowilk_STZ_round_1.csv")
 
  # --- Log-Normal Distribution Tests Round 1 --
 shapirowilk_STZ <- data.frame(Task=1,SW=shapiro.test(log(TimingsSTZ_Order_1[TimingsSTZ_Order_1[2]==1,3]))$p.value)
 for (taskNr in 2:12) {
	 sw <- shapiro.test(log(TimingsSTZ_Order_1[TimingsSTZ_Order_1[2]==taskNr,3]))$p.value
	 shapirowilk_STZ <- rbind(shapirowilk_STZ, c(taskNr,sw))
 }
 write.csv(shapirowilk_STZ,file="shapirowilk_STZ_log_round_1.csv")


# ==================================================
# NORMAL DISTRIBUTION - ROUND 1 KNAVE
# ==================================================

 # --- Normal Distribution Tests - Round 1 --
 shapirowilk_KNAVE <- data.frame(Task=1,SW=shapiro.test(TimingsKNAVE_Order_1[TimingsKNAVE_Order_1[2]==1,3])$p.value)
 for (taskNr in 2:12) {
	 sw <- shapiro.test(TimingsKNAVE_Order_1[TimingsKNAVE_Order_1[2]==taskNr,3])$p.value
	 shapirowilk_KNAVE <- rbind(shapirowilk_KNAVE, c(taskNr,sw))
 }
 write.csv(shapirowilk_KNAVE,file="shapirowilk_KNAVE_round_1.csv")
 
  # --- Log-Normal Distribution Tests Round 1 --
 shapirowilk_KNAVE <- data.frame(Task=1,SW=shapiro.test(log(TimingsKNAVE_Order_1[TimingsKNAVE_Order_1[2]==1,3]))$p.value)
 for (taskNr in 2:12) {
	 sw <- shapiro.test(log(TimingsKNAVE_Order_1[TimingsKNAVE_Order_1[2]==taskNr,3]))$p.value
	 shapirowilk_KNAVE <- rbind(shapirowilk_KNAVE, c(taskNr,sw))
 }
 write.csv(shapirowilk_KNAVE,file="shapirowilk_KNAVE_log_round_1.csv")

# ==================================================
# NORMAL DISTRIBUTION - ROUND 2 STZ
# ==================================================

 # --- Normal Distribution Tests - Round 2 --
 shapirowilk_STZ <- data.frame(Task=1,SW=shapiro.test(TimingsSTZ_Order_2[TimingsSTZ_Order_2[2]==1,3])$p.value)
 for (taskNr in 2:12) {
	 sw <- shapiro.test(TimingsSTZ_Order_2[TimingsSTZ_Order_2[2]==taskNr,3])$p.value
	 shapirowilk_STZ <- rbind(shapirowilk_STZ, c(taskNr,sw))
 }
 write.csv(shapirowilk_STZ,file="shapirowilk_STZ_round_2.csv")
 
  # --- Log-Normal Distribution Tests Round 2 --
 shapirowilk_STZ <- data.frame(Task=1,SW=shapiro.test(log(TimingsSTZ_Order_2[TimingsSTZ_Order_2[2]==1,3]))$p.value)
 for (taskNr in 2:12) {
	 sw <- shapiro.test(log(TimingsSTZ_Order_2[TimingsSTZ_Order_2[2]==taskNr,3]))$p.value
	 shapirowilk_STZ <- rbind(shapirowilk_STZ, c(taskNr,sw))
 }
 write.csv(shapirowilk_STZ,file="shapirowilk_STZ_log_round_2.csv")


# ==================================================
# NORMAL DISTRIBUTION - ROUND 2 KNAVE
# ==================================================

 # --- Normal Distribution Tests - Round 2 --
 shapirowilk_KNAVE <- data.frame(Task=1,SW=shapiro.test(TimingsKNAVE_Order_2[TimingsKNAVE_Order_1[2]==1,3])$p.value)
 for (taskNr in 2:12) {
	 sw <- shapiro.test(TimingsKNAVE_Order_2[TimingsKNAVE_Order_2[2]==taskNr,3])$p.value
	 shapirowilk_KNAVE <- rbind(shapirowilk_KNAVE, c(taskNr,sw))
 }
 write.csv(shapirowilk_KNAVE,file="shapirowilk_KNAVE_round_2.csv")
 
  # --- Log-Normal Distribution Tests Round 1 --
 shapirowilk_KNAVE <- data.frame(Task=1,SW=shapiro.test(log(TimingsKNAVE_Order_2[TimingsKNAVE_Order_2[2]==1,3]))$p.value)
 for (taskNr in 2:12) {
	 sw <- shapiro.test(log(TimingsKNAVE_Order_2[TimingsKNAVE_Order_2[2]==taskNr,3]))$p.value
	 shapirowilk_KNAVE <- rbind(shapirowilk_KNAVE, c(taskNr,sw))
 }
 write.csv(shapirowilk_KNAVE,file="shapirowilk_KNAVE_log_round_2.csv")

# ==================================================
# TESTING FOR EQUAL VARIANCE (F-TEST) - ROUND 1
# ==================================================

 equal_variance_round_1 <- data.frame(Task=1,SW=var.test(log(TimingsSTZ_Order_1[TimingsSTZ_Order_1[2]== "1", "duration_s"]), log(TimingsKNAVE_Order_1[TimingsKNAVE_Order_1[2]== "1", "duration_s"]))$p.value)
 for (taskNr in 2:12) {
 	sw <-var.test(log(TimingsSTZ_Order_1[TimingsSTZ_Order_1[2]== taskNr, "duration_s"]), log(TimingsKNAVE_Order_1[TimingsKNAVE_Order_1[2]== taskNr, "duration_s"]))$p.value
 	equal_variance_round_1 <- rbind(equal_variance_round_1, c(taskNr,sw))
 }
 write.csv(equal_variance_round_1,file="log_equal_variance_round_1.csv")

# ==================================================
# TESTING FOR EQUAL VARIANCE (F-TEST) - ROUND 2
# ==================================================

 equal_variance_round_2 <- data.frame(Task=1,SW=var.test(log(TimingsSTZ_Order_2[TimingsSTZ_Order_2[2]== "1", "duration_s"]), log(TimingsKNAVE_Order_2[TimingsKNAVE_Order_2[2]== "1", "duration_s"]))$p.value)
 for (taskNr in 2:12) {
 	sw <-var.test(log(TimingsSTZ_Order_2[TimingsSTZ_Order_2[2]== taskNr, "duration_s"]), log(TimingsKNAVE_Order_2[TimingsKNAVE_Order_2[2]== taskNr, "duration_s"]))$p.value
 	equal_variance_round_2 <- rbind(equal_variance_round_2, c(taskNr,sw))
 }
 write.csv(equal_variance_round_2,file="log_equal_variance_round_2.csv")


# ==================================================
# T-TEST SINGLE TASKS - ROUND 1
# ==================================================

t_test_round_1 <- data.frame(Task=1,SW=t.test(log(TimingsSTZ_Order_1[TimingsSTZ_Order_1[2]== "1", "duration_s"]), log(TimingsKNAVE_Order_1[TimingsKNAVE_Order_1[2]== "1", "duration_s"]))$p.value)
 for (taskNr in 2:12) {
 	sw <-t.test(log(TimingsSTZ_Order_1[TimingsSTZ_Order_1[2]== taskNr, "duration_s"]), log(TimingsKNAVE_Order_1[TimingsKNAVE_Order_1[2]== taskNr, "duration_s"]))$p.value
 	t_test_round_1 <- rbind(t_test_round_1, c(taskNr,sw))
 }
 write.csv(t_test_round_1,file="t_test_round_1_log.csv")
 
 # ==================================================
# T-TEST SINGLE TASKS - ROUND 2
# ==================================================

t_test_round_2 <- data.frame(Task=1,SW=t.test(log(TimingsSTZ_Order_2[TimingsSTZ_Order_1[2]== "1", "duration_s"]), log(TimingsKNAVE_Order_2[TimingsKNAVE_Order_1[2]== "1", "duration_s"]))$p.value)
 for (taskNr in 2:12) {
 	sw <-t.test(log(TimingsSTZ_Order_2[TimingsSTZ_Order_2[2]== taskNr, "duration_s"]), log(TimingsKNAVE_Order_2[TimingsKNAVE_Order_2[2]== taskNr, "duration_s"]))$p.value
 	t_test_round_2 <- rbind(t_test_round_2, c(taskNr,sw))
 }
 write.csv(t_test_round_2,file="t_test_round_2_log.csv")
 
 # ==================================================
# T-TEST SINGLE TASKS - ROUND 1 - SINGLE SIDED
# ==================================================

t_test_round_1 <- data.frame(Task=1,SW=t.test(log(TimingsSTZ_Order_1[TimingsSTZ_Order_1[2]== "1", "duration_s"]), log(TimingsKNAVE_Order_1[TimingsKNAVE_Order_1[2]== "1", "duration_s"]), alternative = "less")$p.value)
 for (taskNr in 2:12) {
 	sw <-t.test(log(TimingsSTZ_Order_1[TimingsSTZ_Order_1[2]== taskNr, "duration_s"]), log(TimingsKNAVE_Order_1[TimingsKNAVE_Order_1[2]== taskNr, "duration_s"]), alternative = "less")$p.value
 	t_test_round_1 <- rbind(t_test_round_1, c(taskNr,sw))
 }
 write.csv(t_test_round_1,file="t_test_round_1_log_ss.csv")
 
 # ==================================================
# T-TEST SINGLE TASKS - ROUND 2 - SINGLE SIDED
# ==================================================

t_test_round_2 <- data.frame(Task=1,SW=t.test(log(TimingsSTZ_Order_2[TimingsSTZ_Order_1[2]== "1", "duration_s"]), log(TimingsKNAVE_Order_2[TimingsKNAVE_Order_1[2]== "1", "duration_s"]), , alternative = "less")$p.value)
 for (taskNr in 2:12) {
 	sw <-t.test(log(TimingsSTZ_Order_2[TimingsSTZ_Order_2[2]== taskNr, "duration_s"]), log(TimingsKNAVE_Order_2[TimingsKNAVE_Order_2[2]== taskNr, "duration_s"]), alternative = "less")$p.value
 	t_test_round_2 <- rbind(t_test_round_2, c(taskNr,sw))
 }
 write.csv(t_test_round_2,file="t_test_round_2_log_ss.csv")
 

