# Import data
visData <- read.table("raw_data.csv", header=TRUE, sep = ";")
visData <- visData[2:9]
numberOfTasks <- 12
numberOfSubjects <- 20
numberOfDatasets <- 2

# ==================================================
# Calculate error counts and error rates for tasks per interface
# ==================================================
interfaceChars <- c("STZ","KNAVE")


ErrorsTasks <- data.frame(task=numeric(0), interface=character(0), correct=numeric(0), correctness_rate=numeric(0), sd=numeric(0), rate_sd=numeric(0))
for(taskNr in 1:numberOfTasks) {
	for(interfaceNr in 1:length(interfaceChars)) {	
		successCount <- 0
		for(subjectNr in 1:numberOfSubjects) {		
			
			success <- visData[visData[1]==subjectNr & visData[6]==interfaceChars[interfaceNr] & visData[2]==taskNr,4]
			
			if (length(success)>1){
						success_sum <- success[1] + success[2]
						successCount <- successCount + success_sum

				}

		}
		correctnessRate <- successCount/(numberOfSubjects*2)
		correctnessCountSD <- sqrt((numberOfSubjects*2)*correctnessRate*(1-correctnessRate))
		correctnessRateSD <- correctnessCountSD/(numberOfSubjects*2)
		
		ErrorsTasks <- rbind(ErrorsTasks, data.frame(task=taskNr, interface=interfaceChars[interfaceNr], correct=successCount, correctness_rate=correctnessRate, sd=correctnessCountSD, rate_sd=correctnessRateSD))
	} 	
}

# ==================================================
# Bar plot of success rates and standard deviation (Binomial distribution)
# ==================================================
pdf("success-rates-tasks_barplot.pdf",width=11,height=7) 

correctness_rates <- c(ErrorsTasks$correctness_rate)
correctness_rate_table <- matrix(correctness_rates, nrow=numberOfTasks, ncol=length(interfaceChars), byrow=TRUE, dimnames=list(1:numberOfTasks, interfaceChars))
correctnessRateSDs <- c(ErrorsTasks$rate_sd) 
correctnessRateSDs_table <- matrix(correctnessRateSDs, nrow=numberOfTasks, ncol=length(interfaceChars), byrow=TRUE) 

par(xpd = NA)
xpos=barplot(t(correctness_rate_table), beside=TRUE,ylim=c(0,1), col=colors()[c(50,79)], xlab="Task", ylab="Success Rate (%)", axis.lty=1)
segments(xpos, correctness_rates-correctnessRateSDs, xpos, correctness_rates+correctnessRateSDs) 
legend(14, 1.1, c("STZ", "KNAVE"), fill = colors()[c(50,79,91)], bty="n", cex=0.8, hor=TRUE)

dev.off()


# ==================================================
# wilcox on the influence of datasets on errors
# ==================================================
interfaceChars <- c("STZ","KNAVE")
results <- data.frame(task=numeric(0), interface=character(0), dataset=numeric(0), success_count=numeric(0), success_rate=numeric(0))

#success <- visData[visData[1]==subjectNr & visData[6]==interfaceChars[interfaceNr] & visData[2]==taskNr,4]

for(taskNr in 1:12) {
	TaskError <- visData[visData[2]==taskNr, 1:8]
	error_rates <- numeric(0)
	for (datasetNr in 1:2) {
		TaskDatasetError <- TaskError[TaskError[7]==datasetNr, 1:8]
		for (interface in 1:length(interfaceChars)) {
				TaskDatasetInterfaceError <- TaskDatasetError[TaskDatasetError[6]==interfaceChars[interface], 1:8]
				
				count <- length(TaskDatasetInterfaceError$participantId)
				correctnessSum <- sum(TaskDatasetInterfaceError$correctness)
				correctness_rate <- correctnessSum/count
				results <- rbind(results, data.frame(task=taskNr, interface=interfaceChars[interface], dataset=datasetNr, success_count=correctnessSum, success_rate=correctness_rate))
		}	
	}
}

wilcox.test(subset(results, dataset == 1)$success_rate, subset(results, dataset == 2)$success_rate )

# effect size
library(coin)
g <- factor(c(rep("GroupA", length(subset(results, dataset == 1)$success_rate)), rep("GroupB", length(subset(results, dataset == 2)$success_rate))))
v <- c(subset(results, dataset == 1)$success_rate, subset(results, dataset == 2)$success_rate)
wilcox_test(v ~ g, distribution="exact")
r <- rank(v)
data <- data.frame(g, r)
lapply((split(data, data$g)), mean)
0.3654/sqrt(48)

# ==================================================
# wilcox on the influence of order on errors
# ==================================================
interfaceChars <- c("STZ","KNAVE")
results_order <- data.frame(task=numeric(0), interface=character(0), order=numeric(0), success_count=numeric(0), success_rate=numeric(0), rate_sd=numeric(0))

#success <- visData[visData[1]==subjectNr & visData[6]==interfaceChars[interfaceNr] & visData[2]==taskNr,4]

for(taskNr in 1:12) {
	TaskError <- visData[visData[2]==taskNr, 1:8]
	error_rates <- numeric(0)
	for (orderNr in 1:2) {
		TaskOrderError <- TaskError[TaskError[8]== orderNr, 1:8]
		for (interface in 1:length(interfaceChars)) {
				TaskOrderInterfaceError <- TaskOrderError[TaskOrderError[6]==interfaceChars[interface], 1:8]
				
				count <- length(TaskOrderInterfaceError$participantId)
				correctnessSum <- sum(TaskOrderInterfaceError$correctness)
				correctness_rate <- correctnessSum/count
				correctnessCountSD = sqrt (count* correctness_rate * (1-correctness_rate))
				correctnessRateSD = correctnessCountSD/count
					
					
		#			correctnessRate <- successCount/(numberOfSubjects*2)
		#correctnessCountSD <- sqrt((numberOfSubjects*2)*correctnessRate*(1-correctnessRate))
		#correctnessRateSD <- correctnessCountSD/(numberOfSubjects*2)
		
					
								
				
				results_order <- rbind(results_order, data.frame(task=taskNr, interface=interfaceChars[interface], order= orderNr, success_count=correctnessSum, success_rate=correctness_rate, rate_sd= correctnessRateSD))
		}	
	}
}



wilcox.test(subset(results_order, order == 1)$success_rate, subset(results_order, order == 2)$success_rate)

# effect size
library(coin)
g <- factor(c(rep("GroupA", length(subset(results_order, order == 1)$success_rate)), rep("GroupB", length(subset(results_order, order == 2)$success_rate))))
v <- c(subset(results_order, order == 1)$success_rate, subset(results_order, order == 2)$success_rate)
wilcox_test(v ~ g, distribution="exact")
r <- rank(v)
data <- data.frame(g, r)
lapply((split(data, data$g)), mean)
2.1937/sqrt(48)

# ==================================================
# Bar plot of success rates and standard deviation (Binomial distribution) Round 1
# ==================================================
pdf("success-rates-tasks_barplot_round_1.pdf",width=11,height=7) 

correctness_rates <- c(subset(results_order, order == 1)$success_rate)
correctness_rates <- correctness_rates * 100
correctness_rate_table <- matrix(correctness_rates, nrow=numberOfTasks, ncol=length(interfaceChars), byrow=TRUE, dimnames=list(1:numberOfTasks, interfaceChars))
correctnessRateSDs <- c(subset(results_order, order == 1)$rate_sd) 
correctnessRateSDs <- correctnessRateSDs*100
correctnessRateSDs_table <- matrix(correctnessRateSDs, nrow=numberOfTasks, ncol=length(interfaceChars), byrow=TRUE) 

par(xpd = NA)
xpos=barplot(t(correctness_rate_table), beside=TRUE,ylim=c(0,100), col=colors()[c(50,79)], xlab="Task", ylab="Success Rate (%) Round 1", axis.lty=1)
segments(xpos, correctness_rates-correctnessRateSDs, xpos, correctness_rates+correctnessRateSDs) 
legend(14, 110.1, c("STZ", "KNAVE"), fill = colors()[c(50,79,91)], bty="n", cex=0.8, hor=TRUE)

dev.off()

# ==================================================
# Bar plot of success rates and standard deviation (Binomial distribution) Round 2
# ==================================================
pdf("success-rates-tasks_barplot_round_2.pdf",width=11,height=7) 

correctness_rates <- c(subset(results_order, order == 2)$success_rate)
correctness_rates <- correctness_rates * 100
correctness_rate_table <- matrix(correctness_rates, nrow=numberOfTasks, ncol=length(interfaceChars), byrow=TRUE, dimnames=list(1:numberOfTasks, interfaceChars))
correctnessRateSDs <- c(subset(results_order, order == 2)$rate_sd) 
correctnessRateSDs <- correctnessRateSDs*100
correctnessRateSDs_table <- matrix(correctnessRateSDs, nrow=numberOfTasks, ncol=length(interfaceChars), byrow=TRUE) 

par(xpd = NA)
xpos=barplot(t(correctness_rate_table), beside=TRUE,ylim=c(0,100), col=colors()[c(50,79)], xlab="Task", ylab="Success Rate (%) Round 2", axis.lty=1)
segments(xpos, correctness_rates-correctnessRateSDs, xpos, correctness_rates+correctnessRateSDs) 
legend(14, 110.1, c("STZ", "KNAVE"), fill = colors()[c(50,79,91)], bty="n", cex=0.8, hor=TRUE)

dev.off()

# ==================================================
# Analysis on individual task level - Round 1
# ==================================================

groupSTZ <- subset(visData, order == 1 & taskType == 1 & visType == "STZ")$correctness	
groupKNAVE <- subset(visData, order == 1 & taskType == 1 & visType == "KNAVE")$correctness	

g <- factor(c(rep("groupSTZ", length(groupSTZ)), rep("groupKNAVE", length(groupKNAVE))))
v <- c(groupSTZ, groupKNAVE)
	
wt <- wilcox_test(v ~ g, distribution="exact")

wilcox_individual <- data.frame(Task=1, pValue=wilcox.test(groupSTZ,groupKNAVE)$p.value)

wilcox_ties_individual <- data.frame(Task=1, pValue=pvalue(wt))

for(taskNr in 2:12) {
	groupSTZ <- subset(visData, order == 1 & taskType == taskNr & visType == "STZ")$correctness	
	groupKNAVE <- subset(visData, order == 1 & taskType == taskNr & visType == "KNAVE")$correctness	
	
	g <- factor(c(rep("groupSTZ", length(groupSTZ)), rep("groupKNAVE", length(groupKNAVE))))
	v <- c(groupSTZ, groupKNAVE)
	
	wt <- wilcox_test(v ~ g, distribution="exact")
	
	wilcox_individual <- rbind(wilcox_individual, c(taskNr,wilcox.test(groupSTZ,groupKNAVE)$p.value))
	
	wilcox_ties_individual <-  rbind(wilcox_ties_individual, c(taskNr,pvalue(wt)))
}

write.csv(wilcox_individual,file="error_individual_wilcox_round_1.csv")
write.csv(wilcox_ties_individual,file="error_individual_wilcox_ties_round_1.csv")

# ==================================================
# Analysis on individual task level - Round 2
# ==================================================

groupSTZ <- subset(visData, order == 2 & taskType == 1 & visType == "STZ")$correctness	
groupKNAVE <- subset(visData, order == 2 & taskType == 1 & visType == "KNAVE")$correctness	

g <- factor(c(rep("groupSTZ", length(groupSTZ)), rep("groupKNAVE", length(groupKNAVE))))
v <- c(groupSTZ, groupKNAVE)
	
wt <- wilcox_test(v ~ g, distribution="exact")

wilcox_individual <- data.frame(Task=1, pValue=wilcox.test(groupSTZ,groupKNAVE)$p.value)

wilcox_ties_individual <- data.frame(Task=1, pValue=pvalue(wt))

for(taskNr in 2:12) {
	groupSTZ <- subset(visData, order == 2 & taskType == taskNr & visType == "STZ")$correctness	
	groupKNAVE <- subset(visData, order == 2 & taskType == taskNr & visType == "KNAVE")$correctness	
	
	if (!identical(groupSTZ, groupKNAVE)){
	
	g <- factor(c(rep("groupSTZ", length(groupSTZ)), rep("groupKNAVE", length(groupKNAVE))))
	v <- c(groupSTZ, groupKNAVE)
	
	wt <- wilcox_test(v ~ g, distribution="exact")
	
	wilcox_individual <- rbind(wilcox_individual, c(taskNr,wilcox.test(groupSTZ,groupKNAVE)$p.value))
	
	wilcox_ties_individual <-  rbind(wilcox_ties_individual, c(taskNr,pvalue(wt)))
	}
}

write.csv(wilcox_individual,file="error_individual_wilcox_round_2.csv")
write.csv(wilcox_ties_individual,file="error_individual_wilcox_ties_round_2.csv")


