# ==================================================
# HYPOTHESES - ERROR RATE
# ==================================================
# Import data
visData <- read.table("raw_data.csv", header=TRUE, sep = ";")
visData <- visData[2:9]

numberOfSubjects <- 20
numberOfDatasets <- 2


# ==================================================
# Calculate error counts and error rates for hypotheses
# Round 1  
# ==================================================

interfaceChars <- c("STZ","KNAVE")
hypothesesNames <- c("H1.1","H1.2","H2.1","H2.2")
taskNrH11 <- c(1,2,3)
taskNrH12 <- c(4,5,6)
taskNrH21 <- c(7,8,9)
taskNrH22 <- c(10,11,12)

taskNrHypotheses <- list(taskNrH11, taskNrH12, taskNrH21, taskNrH22)
interfacesH11 <- c("STZ","KNAVE")
interfacesH12 <- c("STZ","KNAVE")
interfacesH21 <- c("STZ","KNAVE")
interfacesH22 <- c("STZ","KNAVE")

interfacesHypotheses <- list(interfacesH11, interfacesH12, interfacesH21, interfacesH22)


ErrorsHypotheses_round_1 <- data.frame(subject=numeric(0), hypothesis=character(0), interface=character(0), errors=numeric(0), error_rate=numeric(0), success_rate=numeric(0) )
for (subjectNr in 1:numberOfSubjects) {
	for(hypothesesNr in 1:length(hypothesesNames)) {
		interfacesForHy <- interfacesHypotheses[[hypothesesNr]]
		numberOfTasksForHy <- length(taskNrHypotheses[[hypothesesNr]])
		tasksForHy <- taskNrHypotheses[[hypothesesNr]]
		for(interfaceNr in 1:length(interfacesForHy)) {		
			successCount <- 0
			taskset <- numeric(0)
			tasksuccess <- character(0)
			for(i in 1:numberOfTasksForHy) {
				success <- visData[visData[1]==subjectNr & visData[8] == 1 & visData[6]==interfacesForHy[interfaceNr] & visData[2]==tasksForHy[i],4]
				
				if (length(success)>1){
						success_sum <- success[1] + success[2]
						successCount <- successCount + success_sum
						taskset <- c(taskset, tasksForHy[i])
						tasksuccess <- c(tasksuccess, success)

				}
				
				
			} 
			
			if (length(taskset)>0){
				errorCount <- (numberOfTasksForHy*2) - successCount
				errorRate <- errorCount/(numberOfTasksForHy*2)
				ErrorsHypotheses_round_1 <- rbind(ErrorsHypotheses_round_1, data.frame(subject=subjectNr, hypothesis=hypothesesNames[hypothesesNr], interface=interfacesForHy[interfaceNr], errors=errorCount, error_rate=errorRate, success_rate = (1-errorRate) ))
			}
			
			#hyp <- hypothesesNames[hypothesesNr]
			#int <- interfacesForHy[interfaceNr]
			#text <- c(text, "subject", subjectNr, "hypotheses", hyp, "interface", int, "errorCount", errorCount, "taskSet", taskset, "task success", tasksuccess, "numberOfTasks", numberOfTasksForHy)
		}
	}
}

# ==================================================
# Summary Statistics
# ==================================================
sumstats_hypotheses_errors_round_1 <- data.frame(hypothesis=character(0), interface=character(0), MIN=numeric(0), Q1=numeric(0), MEDIAN=numeric(0), MEAN=numeric(0), Q3=numeric(0), MAX=numeric(0), SD=numeric(0))

for(hypothesesNr in 1:length(hypothesesNames)) {
	interfacesForHy <- interfacesHypotheses[[hypothesesNr]]
	for(interfaceNr in 1:length(interfacesForHy)) {		
		error_rates <- ErrorsHypotheses_round_1[ErrorsHypotheses_round_1[3]==interfacesForHy[interfaceNr] & ErrorsHypotheses_round_1[2]==hypothesesNames[hypothesesNr],5]
		sumstats_hypotheses_errors_round_1 <- rbind(sumstats_hypotheses_errors_round_1, data.frame(hypothesis=hypothesesNames[hypothesesNr], interface=interfacesForHy[interfaceNr], MIN=min(error_rates), Q1=quantile(error_rates,0.25), MEDIAN=median(error_rates), MEAN=mean(error_rates), Q3=quantile(error_rates,0.75), MAX=max(error_rates), SD=sd(error_rates)))
	}
}

write.csv(sumstats_hypotheses_errors_round_1,file="sumstats_hypotheses_errors_round_1.csv")

# ==================================================
# Boxplot Error Rates - ALL in single plot
# ==================================================
boxplot(error_rate ~ interface * hypothesis, data = ErrorsHypotheses_round_1, main="Error rates of hypotheses", xlab="Tasks", ylab="Error rate", col = colors()[c(50,79)], boxwex = 0.5)


# ==================================================
# Test for normal distribution
# ==================================================
shapirowilk_H_round_1 <- data.frame(Hypothesis=character(0),Interface=character(0),SW=numeric(0))
interfaceChars <- c("STZ","KNAVE")
for (hypothesisNr in 1:4) {
	#hypothesisString <- paste("H",hypothesisNr,sep="")
	hypothesisString <- hypothesesNames[hypothesisNr]
	ErrorsH <- ErrorsHypotheses_round_1[ErrorsHypotheses_round_1[2]==hypothesisString,1:6]
	for(interfaceNr in 1:2) {
		success_rates <- ErrorsH[ErrorsH[3]==interfaceChars[interfaceNr],6]
		if(length(success_rates)>0) {
			sw <- shapiro.test(success_rates)$p.value
			shapirowilk_H_round_1 <- rbind(shapirowilk_H_round_1, data.frame(Hypothesis=hypothesisString,Interface=interfaceChars[interfaceNr],SW=sw))
		}
	}	
}
write.csv(shapirowilk_H_round_1,file="shapirowilk_hypotheses_errors_round_1.csv")

# ==================================================
# Test for log-normal distribution
# ==================================================
shapirowilk_H_round_1_log <- data.frame(Hypothesis=character(0),Interface=character(0),SW=numeric(0))
interfaceChars <- c("STZ","KNAVE")
for (hypothesisNr in 1:4) {
	hypothesisString <- hypothesesNames[hypothesisNr]
	ErrorsH <- ErrorsHypotheses_round_1[ErrorsHypotheses_round_1[2]==hypothesisString,1:6]
	for(interfaceNr in 1:2) {
		success_rates <- ErrorsH[ErrorsH[3]==interfaceChars[interfaceNr], 6]
		if(length(success_rates)>0) {
			sw <- shapiro.test(log(success_rates))$p.value
			shapirowilk_H_round_1_log <- rbind(shapirowilk_H_round_1_log, data.frame(Hypothesis=hypothesisString,Interface=interfaceChars[interfaceNr],SW=sw))
		}
	}	
}
write.csv(shapirowilk_H_round_1_log,file="shapirowilk_hypotheses_log_errors_round_1.csv")

# ==================================================
# Test for equal variances (F test)
# ==================================================

equal_var <- data.frame(Hypothesis="Hx",SW=0.0)
	
	# H1.1 
	sw <- var.test(ErrorsHypotheses_round_1[ErrorsHypotheses_round_1[2]=="H1.1" & ErrorsHypotheses_round_1[3]=="STZ", "error_rate"], ErrorsHypotheses_round_1[ErrorsHypotheses_round_1[2]=="H1.1" & ErrorsHypotheses_round_1[3]=="KNAVE", "error_rate"])$p.value
	
	equal_var <- rbind(equal_var, data.frame(Hypothesis="H1.1",SW=sw))
	
	# H1.2 
	sw <- var.test(ErrorsHypotheses_round_1[ErrorsHypotheses_round_1[2]=="H1.2" & ErrorsHypotheses_round_1[3]=="STZ", "error_rate"], ErrorsHypotheses_round_1[ErrorsHypotheses_round_1[2]=="H1.2" & ErrorsHypotheses_round_1[3]=="KNAVE", "error_rate"])$p.value
	
	equal_var <- rbind(equal_var, data.frame(Hypothesis="H1.2",SW=sw))
	
	# H2.1
	sw <- var.test(ErrorsHypotheses_round_1[ErrorsHypotheses_round_1[2]=="H2.1" & ErrorsHypotheses_round_1[3]=="STZ", "error_rate"], ErrorsHypotheses_round_1[ErrorsHypotheses_round_1[2]=="H2.1" & ErrorsHypotheses_round_1[3]=="KNAVE", "error_rate"])$p.value
	
	equal_var <- rbind(equal_var, data.frame(Hypothesis="H2.1",SW=sw))
	
	# H2.2
	sw <- var.test(ErrorsHypotheses_round_1[ErrorsHypotheses_round_1[2]=="H2.2" & ErrorsHypotheses_round_1[3]=="STZ", "error_rate"], ErrorsHypotheses_round_1[ErrorsHypotheses_round_1[2]=="H2.2" & ErrorsHypotheses_round_1[3]=="KNAVE", "error_rate"])$p.value
	
	equal_var <- rbind(equal_var, data.frame(Hypothesis="H2.2",SW=sw))
	
	write.csv(equal_var,file="error_hypothesis_equal_variance_round_1.csv")

# --> h2.1 not equal variance 

# ==================================================
# Wilcoxon rank sum test
# ==================================================


 wilcox.test(ErrorsHypotheses_round_1[ErrorsHypotheses_round_1[2]=="H1.1" & ErrorsHypotheses_round_1[3]=="STZ", "error_rate"], ErrorsHypotheses_round_1[ErrorsHypotheses_round_1[2]=="H1.1" & ErrorsHypotheses_round_1[3]=="KNAVE", "error_rate"])

# # H1.1 
 # t.test(TimingsHypothesesRound2[TimingsHypothesesRound2[2]=="H1.1" & TimingsHypothesesRound2[3]=="STZ", "time_s"], TimingsHypothesesRound2[TimingsHypothesesRound2[2]=="H1.1" & TimingsHypothesesRound2[3]=="KNAVE", "time_s"], paired = F, alternative="less")$p.value

# t_test <- rbind(t_test, data.frame(Hypothesis="H1.1",SW=sw))



# ==================================================
# Calculate error counts and error rates for hypotheses
# Round 2  
# ==================================================

ErrorsHypotheses_round_2 <- data.frame(subject=numeric(0), hypothesis=character(0), interface=character(0), errors=numeric(0), error_rate=numeric(0))
for (subjectNr in 1:numberOfSubjects) {
	for(hypothesesNr in 1:length(hypothesesNames)) {
		interfacesForHy <- interfacesHypotheses[[hypothesesNr]]
		numberOfTasksForHy <- length(taskNrHypotheses[[hypothesesNr]])
		tasksForHy <- taskNrHypotheses[[hypothesesNr]]
		for(interfaceNr in 1:length(interfacesForHy)) {		
			successCount <- 0
			taskset <- numeric(0)
			tasksuccess <- character(0)
			for(i in 1:numberOfTasksForHy) {
				success <- visData[visData[1]==subjectNr & visData[8] == 2 & visData[6]==interfacesForHy[interfaceNr] & visData[2]==tasksForHy[i],4]
				
				if (length(success)>1){
						success_sum <- success[1] + success[2]
						successCount <- successCount + success_sum
						taskset <- c(taskset, tasksForHy[i])
						tasksuccess <- c(tasksuccess, success)

				}
				
				
			} 
			
			if (length(taskset)>0){
				errorCount <- (numberOfTasksForHy*2) - successCount
				errorRate <- errorCount/(numberOfTasksForHy*2)
				ErrorsHypotheses_round_2 <- rbind(ErrorsHypotheses_round_2, data.frame(subject=subjectNr, hypothesis=hypothesesNames[hypothesesNr], interface=interfacesForHy[interfaceNr], errors=errorCount, error_rate=errorRate))
			}
			
			#hyp <- hypothesesNames[hypothesesNr]
			#int <- interfacesForHy[interfaceNr]
			#text <- c(text, "subject", subjectNr, "hypotheses", hyp, "interface", int, "errorCount", errorCount, "taskSet", taskset, "task success", tasksuccess, "numberOfTasks", numberOfTasksForHy)
		}
	}
}

# ==================================================
# Summary Statistics
# ==================================================
sumstats_hypotheses_errors_round_2 <- data.frame(hypothesis=character(0), interface=character(0), MIN=numeric(0), Q1=numeric(0), MEDIAN=numeric(0), MEAN=numeric(0), Q3=numeric(0), MAX=numeric(0), SD=numeric(0))

for(hypothesesNr in 1:length(hypothesesNames)) {
	interfacesForHy <- interfacesHypotheses[[hypothesesNr]]
	for(interfaceNr in 1:length(interfacesForHy)) {		
		error_rates <- ErrorsHypotheses_round_2[ErrorsHypotheses_round_2[3]==interfacesForHy[interfaceNr] & ErrorsHypotheses_round_2[2]==hypothesesNames[hypothesesNr],5]
		sumstats_hypotheses_errors_round_2 <- rbind(sumstats_hypotheses_errors_round_2, data.frame(hypothesis=hypothesesNames[hypothesesNr], interface=interfacesForHy[interfaceNr], MIN=min(error_rates), Q1=quantile(error_rates,0.25), MEDIAN=median(error_rates), MEAN=mean(error_rates), Q3=quantile(error_rates,0.75), MAX=max(error_rates), SD=sd(error_rates)))
	}
}

write.csv(sumstats_hypotheses_errors_round_2,file="sumstats_hypotheses_errors_round_2.csv")

# ==================================================
# Boxplot Error Rates - ALL in single plot
# ==================================================
boxplot(error_rate ~ interface * hypothesis, data = ErrorsHypotheses_round_2, main="Error rates of hypotheses", xlab="Tasks", ylab="Error rate", col = colors()[c(50,79)], boxwex = 0.5)

# ==================================================
# Test for equal variances (F test)
# ==================================================

equal_var <- data.frame(Hypothesis="Hx",SW=0.0)
	
	# H1.1 
	sw <- var.test(ErrorsHypotheses_round_2[ErrorsHypotheses_round_2[2]=="H1.1" & ErrorsHypotheses_round_2[3]=="STZ", "error_rate"], ErrorsHypotheses_round_2[ErrorsHypotheses_round_2[2]=="H1.1" & ErrorsHypotheses_round_2[3]=="KNAVE", "error_rate"])$p.value
	
	equal_var <- rbind(equal_var, data.frame(Hypothesis="H1.1",SW=sw))
	
	# H1.2 
	sw <- var.test(ErrorsHypotheses_round_2[ErrorsHypotheses_round_2[2]=="H1.2" & ErrorsHypotheses_round_2[3]=="STZ", "error_rate"], ErrorsHypotheses_round_2[ErrorsHypotheses_round_2[2]=="H1.2" & ErrorsHypotheses_round_2[3]=="KNAVE", "error_rate"])$p.value
	
	equal_var <- rbind(equal_var, data.frame(Hypothesis="H1.2",SW=sw))
	
	# H2.1
	sw <- var.test(ErrorsHypotheses_round_2[ErrorsHypotheses_round_2[2]=="H2.1" & ErrorsHypotheses_round_2[3]=="STZ", "error_rate"], ErrorsHypotheses_round_2[ErrorsHypotheses_round_2[2]=="H2.1" & ErrorsHypotheses_round_2[3]=="KNAVE", "error_rate"])$p.value
	
	equal_var <- rbind(equal_var, data.frame(Hypothesis="H2.1",SW=sw))
	
	# H2.2
	sw <- var.test(ErrorsHypotheses_round_2[ErrorsHypotheses_round_2[2]=="H2.2" & ErrorsHypotheses_round_2[3]=="STZ", "error_rate"], ErrorsHypotheses_round_2[ErrorsHypotheses_round_2[2]=="H2.2" & ErrorsHypotheses_round_2[3]=="KNAVE", "error_rate"])$p.value
	
	equal_var <- rbind(equal_var, data.frame(Hypothesis="H2.2",SW=sw))
	
	write.csv(equal_var,file="error_hypothesis_equal_variance_round_2.csv")

# --> h1.1 not equal variance 

# # ==================================================
# # Boxplot Error Rates - on top of each other
# # ==================================================
# pdf("errorBoxplots-hypotheses.pdf",width=3,height=20) 
# par(mfrow=c(5,1),mar=c(5,5,2,2)) 
# for (hypothesisNr in 1:5) {
	# hypothesisString <- paste("H",hypothesisNr,sep="")
	# boxplot(error_rate ~ interface, data = ErrorsHypotheses, subset = hypothesis==hypothesisString, main=hypothesisString, xlab="Interface", ylab="Error rate", col = colors()[c(50,79,91)], boxwex=0.5, ylim=c(0, 1))
	# legend("bottomleft", c("Juxtaposition (A)", "Superimposition (B)", "Indexing (C)"),
       # fill = colors()[c(50,79,91)], bty="n", cex=0.8)
# }
# dev.off()

# # ==================================================
# # Boxplot Error Rates - in a row
# # ==================================================
# pdf("errorBoxplots-hypotheses-row.pdf",width=10,height=4) 
# par(mfrow=c(1,5),mar=c(7,5,2,2),xpd=NA) 
# for (hypothesisNr in 1:5) {
	# hypothesisString <- paste("H",hypothesisNr,sep="")
	# boxplot(error_rate ~ interface, data = ErrorsHypotheses, subset = hypothesis==hypothesisString, main=hypothesisString, ylab="Error rate", col = colors()[c(50,79,91)], boxwex=0.5, ylim=c(0, 1), cex.lab=1.4, cex.axis=1.0, cex.main=1.6, names = c("Li+J", "Lo+S", "I"), whisklty="solid")
	# #legend("topright", c("Juxtaposition (A)", "Superimposition (B)", "Indexing (C)"), fill = colors()[c(50,79,91)], bty="n", cex=0.8)
# }
# legend(-13, -0.2, c("Li+J", "Lo+S", "I"), fill = colors()[c(50,79,91)], bty="n", cex=1.4, hor=TRUE)
# dev.off()

# # ==================================================
# # Histogram Lattice of error rates
# # ==================================================
# pdf("errorHistogram_hypotheses_lattice.pdf",width=11,height=9) 
# par(mar=c(5,5,1,2)) 
# library(lattice)

# ## Set background color of strips to grayscales: 
# strip.background <- trellis.par.get("strip.background") 
# trellis.par.set(strip.background = list(col = grey(7:1/8)))
# strip.border <- trellis.par.get("strip.border") 
# trellis.par.set(strip.border = list(col = grey(7:1/8)))
# axis.line <- trellis.par.get("axis.line") 
# trellis.par.set(axis.line = list(col = grey(7:1/8)))

# histogram(~error_rate | interface * hypothesis, nint=10, data=ErrorsHypotheses, type="density", layout = c(3,5), as.table=TRUE, col = c("darkslategrey"), border = "white", xlab="Task set error rate (%)", ylab="Count")

# dev.off()

# # ==================================================
# # Histogram and density trace
# # ==================================================
# hist(ErrorsHypotheses[ErrorsHypotheses[2]=="H2" & ErrorsHypotheses[3]=="C",5], seq(0,1,0.1), prob=TRUE)
# lines(density(ErrorsHypotheses[ErrorsHypotheses[2]=="H2" & ErrorsHypotheses[3]=="C",5],adjust=2))

# hist(log(ErrorsHypotheses[ErrorsHypotheses[2]=="H2" & ErrorsHypotheses[3]=="C",5]), prob=TRUE)
# lines(density(log(ErrorsHypotheses[ErrorsHypotheses[2]=="H2" & ErrorsHypotheses[3]=="C",5])),adjust=2)

# # # ==================================================
# # Test for normal distribution
# # ==================================================
# shapirowilk_H <- data.frame(Hypothesis=character(0),Interface=character(0),SW=numeric(0))
# interfaceChars <- c("A","B","C")
# for (hypothesisNr in 1:5) {
	# hypothesisString <- paste("H",hypothesisNr,sep="")
	# ErrorsH <- ErrorsHypotheses[ErrorsHypotheses[2]==hypothesisString,1:5]
	# for(interfaceNr in 1:3) {
		# error_rates <- ErrorsH[ErrorsH[3]==interfaceChars[interfaceNr],5]
		# if(length(error_rates)>0) {
			# sw <- shapiro.test(error_rates)$p.value
			# shapirowilk_H <- rbind(shapirowilk_H, data.frame(Hypothesis=hypothesisString,Interface=interfaceChars[interfaceNr],SW=sw))
		# }
	# }	
# }
# write.csv(shapirowilk_H,file="shapirowilk_hypotheses_errors.txt")

# # ==================================================
# # Test for log-normal distribution
# # ==================================================
# shapirowilk_H_log <- data.frame(Hypothesis=character(0),Interface=character(0),SW=numeric(0))
# interfaceChars <- c("A","B","C")
# for (hypothesisNr in 1:5) {
	# hypothesisString <- paste("H",hypothesisNr,sep="")
	# ErrorsH <- ErrorsHypotheses[ErrorsHypotheses[2]==hypothesisString,1:5]
	# for(interfaceNr in 1:3) {
		# error_rates <- ErrorsH[ErrorsH[3]==interfaceChars[interfaceNr] & ErrorsH[5]>0, 5]
		# if(length(error_rates)>0) {
			# sw <- shapiro.test(log(error_rates))$p.value
			# shapirowilk_H_log <- rbind(shapirowilk_H_log, data.frame(Hypothesis=hypothesisString,Interface=interfaceChars[interfaceNr],SW=sw))
		# }
	# }	
# }
# write.csv(shapirowilk_H_log,file="shapirowilk_hypotheses_log_errors.txt")

# # ==================================================
# # Testing for equal variance (F-Test)
# # ==================================================
# # H1 (A vs. B)
# var.test(ErrorsHypotheses[ErrorsHypotheses[2]=="H1" & ErrorsHypotheses[3]=="A", "error_rate"], ErrorsHypotheses[ErrorsHypotheses[2]=="H1" & ErrorsHypotheses[3]=="B", "error_rate"])

# # H2 (B vs. C)
	# var.test(ErrorsHypotheses[ErrorsHypotheses[2]=="H2" & ErrorsHypotheses[3]=="B", "error_rate"], ErrorsHypotheses[ErrorsHypotheses[2]=="H2" & ErrorsHypotheses[3]=="C", "error_rate"])

# # H2 (B vs. C) - log
# var.test(log(ErrorsHypotheses[ErrorsHypotheses[2]=="H2" & ErrorsHypotheses[3]=="B", "error_rate"]), log(ErrorsHypotheses[ErrorsHypotheses[2]=="H2" & ErrorsHypotheses[3]=="C", "error_rate"]))

# # H3 (A vs. B vs. C)
# var.test(ErrorsHypotheses[ErrorsHypotheses[2]=="H3" & ErrorsHypotheses[3]=="A", "error_rate"], ErrorsHypotheses[ErrorsHypotheses[2]=="H3" & ErrorsHypotheses[3]=="B", "error_rate"])
# var.test(ErrorsHypotheses[ErrorsHypotheses[2]=="H3" & ErrorsHypotheses[3]=="A", "error_rate"], ErrorsHypotheses[ErrorsHypotheses[2]=="H3" & ErrorsHypotheses[3]=="C", "error_rate"])
# var.test(ErrorsHypotheses[ErrorsHypotheses[2]=="H3" & ErrorsHypotheses[3]=="B", "error_rate"], ErrorsHypotheses[ErrorsHypotheses[2]=="H3" & ErrorsHypotheses[3]=="C", "error_rate"])

# # H4 (A vs. B)
# var.test((ErrorsHypotheses[ErrorsHypotheses[2]=="H4" & ErrorsHypotheses[3]=="A", "error_rate"]), (ErrorsHypotheses[ErrorsHypotheses[2]=="H4" & ErrorsHypotheses[3]=="B", "error_rate"]))

# # H5 (A vs. B vs. C)
# var.test(log(ErrorsHypotheses[ErrorsHypotheses[2]=="H5" & ErrorsHypotheses[3]=="A", "error_rate"]), log(ErrorsHypotheses[ErrorsHypotheses[2]=="H5" & ErrorsHypotheses[3]=="B", "error_rate"]))
# var.test(log(ErrorsHypotheses[ErrorsHypotheses[2]=="H5" & ErrorsHypotheses[3]=="A", "error_rate"]), log(ErrorsHypotheses[ErrorsHypotheses[2]=="H5" & ErrorsHypotheses[3]=="C", "error_rate"]))
# var.test(log(ErrorsHypotheses[ErrorsHypotheses[2]=="H5" & ErrorsHypotheses[3]=="B", "error_rate"]), log(ErrorsHypotheses[ErrorsHypotheses[2]=="H5" & ErrorsHypotheses[3]=="C", "error_rate"]))

# # ==================================================
# # Wilcoxon-Test for H1 (A vs. B)
# # ==================================================
# a <- ErrorsHypotheses[ErrorsHypotheses[2]=="H1" & ErrorsHypotheses[3]=="A", "error_rate"]
# b <- ErrorsHypotheses[ErrorsHypotheses[2]=="H1" & ErrorsHypotheses[3]=="B", "error_rate"]
# wilcox.test(a, b, paired=T)

# # ==================================================
# # Wilcoxon-Test for H2 (B vs. C)
# # ==================================================
# a <- ErrorsHypotheses[ErrorsHypotheses[2]=="H2" & ErrorsHypotheses[3]=="B", "error_rate"]
# b <- ErrorsHypotheses[ErrorsHypotheses[2]=="H2" & ErrorsHypotheses[3]=="C", "error_rate"]
# wilcox.test(a, b, paired=T)

# # ==================================================
# # Wilcoxon-Test for H4 (A vs. B)
# # ==================================================
# a <- ErrorsHypotheses[ErrorsHypotheses[2]=="H4" & ErrorsHypotheses[3]=="A", "error_rate"]
# b <- ErrorsHypotheses[ErrorsHypotheses[2]=="H4" & ErrorsHypotheses[3]=="B", "error_rate"]
# wilcox.test(a, b, paired=T)

# # ==================================================
# # Kruskal-Wallis test (non-parametric) for H5 (A vs. B vs. C)
# # ==================================================
# errorsH5 <- ErrorsHypotheses[ErrorsHypotheses[2]=="H5", 1:5]
# kruskal.test(error_rate~interface,errorsH5)

# # ==================================================
# # Wilcoxon-Test for H5a (A vs. C)
# # ==================================================
# a <- ErrorsHypotheses[ErrorsHypotheses[2]=="H5" & ErrorsHypotheses[3]=="A", "error_rate"]
# b <- ErrorsHypotheses[ErrorsHypotheses[2]=="H5" & ErrorsHypotheses[3]=="C", "error_rate"]
# wilcox.test(a, b)

# # ==================================================
# # Wilcoxon-Test for H5b (B vs. C)
# # ==================================================
# a <- ErrorsHypotheses[ErrorsHypotheses[2]=="H5" & ErrorsHypotheses[3]=="B", "error_rate"]
# b <- ErrorsHypotheses[ErrorsHypotheses[2]=="H5" & ErrorsHypotheses[3]=="C", "error_rate"]
# wilcox.test(a, b)

# # ==================================================
# # Wilcoxon-Test for H5c (A vs. B)
# # ==================================================
# a <- ErrorsHypotheses[ErrorsHypotheses[2]=="H5" & ErrorsHypotheses[3]=="A", "error_rate"]
# b <- ErrorsHypotheses[ErrorsHypotheses[2]=="H5" & ErrorsHypotheses[3]=="B", "error_rate"]
# wilcox.test(a, b)

# # ==================================================
# # Friedman test (non-parametric, repeated measures) for H3
# # ==================================================
# errorsH3 <- cbind(ErrorsHypotheses[ErrorsHypotheses[2]=="H3" & ErrorsHypotheses[3]=="A", 4], ErrorsHypotheses[ErrorsHypotheses[2]=="H3" & ErrorsHypotheses[3]=="B", 4], ErrorsHypotheses[ErrorsHypotheses[2]=="H3" & ErrorsHypotheses[3]=="C", 4])
# friedman.test(errorsH3)

# # ==================================================
# # Post-hoc test for H3
# # ==================================================
# errorsH3 <- ErrorsHypotheses[ErrorsHypotheses[2]=="H3", 1:5]
# pairwise.wilcox.test(errorsH3$error_rate, errorsH3$interface, p.adj="bonferroni", exact=F, paired=T)

# # ==================================================
# # Friedman test (non-parametric, repeated measures) for H5
# # ==================================================
# errorsH5 <- cbind(ErrorsHypotheses[ErrorsHypotheses[2]=="H5" & ErrorsHypotheses[3]=="A", 4], ErrorsHypotheses[ErrorsHypotheses[2]=="H5" & ErrorsHypotheses[3]=="B", 4], ErrorsHypotheses[ErrorsHypotheses[2]=="H5" & ErrorsHypotheses[3]=="C", 4])
# friedman.test(errorsH5)

# # ==================================================
# # Post-hoc test for H5
# # ==================================================
# errorsH5 <- ErrorsHypotheses[ErrorsHypotheses[2]=="H5", 1:5]
# pairwise.wilcox.test(errorsH5$error_rate, errorsH5$interface, p.adj="bonferroni", exact=F, paired=T)


# # ==================================================
# # Kruskal-Wallis test (non-parametric) for H3 (A vs. B vs. C)
# # ==================================================
# errorsH3 <- ErrorsHypotheses[ErrorsHypotheses[2]=="H3", 1:5]
# kruskal.test(error_rate~interface,errorsH3)

# # ==================================================
# # Wilcoxon-Test for H3a (A vs. C)
# # ==================================================
# a <- ErrorsHypotheses[ErrorsHypotheses[2]=="H3" & ErrorsHypotheses[3]=="A", "error_rate"]
# b <- ErrorsHypotheses[ErrorsHypotheses[2]=="H3" & ErrorsHypotheses[3]=="C", "error_rate"]
# wilcox.test(a, b)

# # ==================================================
# # Wilcoxon-Test for H3b (B vs. C)
# # ==================================================
# a <- ErrorsHypotheses[ErrorsHypotheses[2]=="H3" & ErrorsHypotheses[3]=="B", "error_rate"]
# b <- ErrorsHypotheses[ErrorsHypotheses[2]=="H3" & ErrorsHypotheses[3]=="C", "error_rate"]
# wilcox.test(a, b)

# # ==================================================
# # Wilcoxon-Test for H3c (A vs. B)
# # ==================================================
# a <- ErrorsHypotheses[ErrorsHypotheses[2]=="H3" & ErrorsHypotheses[3]=="A", "error_rate"]
# b <- ErrorsHypotheses[ErrorsHypotheses[2]=="H3" & ErrorsHypotheses[3]=="B", "error_rate"]
# wilcox.test(a, b)

# # ==================================================
# # One-way analysis of variance (ANOVA)
# # ==================================================
# # H3 (A vs. B vs. C)
# errorsH3 <- ErrorsHypotheses[ErrorsHypotheses[2]=="H3", 1:5]
# aov.H3= aov(error_rate~interface,errorsH3)
# summary(aov.H3)
# print(model.tables(aov.H3,"means"),digits=3)

# # ==================================================
# # Kruskal-Wallis test (non-parametric)
# # ==================================================
# errorsH5 <- ErrorsHypotheses[ErrorsHypotheses[2]=="H5", 1:5]
# kruskal.test(error_rate~interface,errorsH5)


# # ==================================================
# # Histogram lattice of Dataset usage per Hypothesis
# # ==================================================
# datasetCounts <- data.frame(Hypothesis=character(0),Dataset=numeric(0),count=numeric(0))

# for(hypothesesNr in 1:length(hypothesesNames)) {
	# numberOfTasksForHy <- length(taskNrHypotheses[[hypothesesNr]])
	# tasksForHy <- taskNrHypotheses[[hypothesesNr]]
	# hypothesisString <- paste("H",hypothesesNr,sep="")
	# datasetTempCounts = c(0,0,0)
	# for(i in 1:numberOfTasksForHy) {
		# for(j in 1:numberOfDatasets) {
			# datasetTempCounts[j] = datasetTempCounts[j] + length(FinanceVisData[FinanceVisData[3]==tasksForHy[i] & FinanceVisData[6]==j,6])
		# }
	# }
	# for(i in 1:numberOfDatasets) {
		# datasetCounts <- rbind(datasetCounts, data.frame(Hypothesis=hypothesisString,Dataset=i,count=datasetTempCounts[i]))
	# }
# }

# pdf("datasets-usage-per-hypothesis_lattice.pdf",width=7,height=4) 
# library(lattice)

# ## Set background color of strips to grayscales: 
# strip.background <- trellis.par.get("strip.background") 
# trellis.par.set(strip.background = list(col = grey(7:1/8)))
# strip.border <- trellis.par.get("strip.border") 
# trellis.par.set(strip.border = list(col = grey(7:1/8)))
# axis.line <- trellis.par.get("axis.line") 
# trellis.par.set(axis.line = list(col = grey(7:1/8)))

# barchart(count ~ Dataset | as.factor(Hypothesis), data=datasetCounts, ylim=c(0,410), layout = c(5,1), horiz=FALSE, ylab = "Count of Tasks", col = colors()[c(131,655,640)], border="white")	

# dev.off()

# # ==================================================
# # One-way analysis of variance (ANOVA) - Comparison between subjects per interface
# # ==================================================
# results <- character(0)
# ErrorsInterface <- ErrorsHypotheses[ErrorsHypotheses[3]=="A", 1:5]
# for (hypothesesNr in 1:length(hypothesesNames)) {
	# errorsHypothesis <- ErrorsInterface[ErrorsInterface[2]==hypothesesNames[hypothesesNr], 1:5]
	# aov.T = aov(error_rate~subject,errorsHypothesis)
	# results <- c(results, summary(aov.T))
	# #print(model.tables(aov.T,"means"),digits=3)
# }