# ==================================================
# HYPOTHESES - TASK COMPLETION TIME
# ==================================================
# Import data

# Import data
aggregatedData <- read.table("raw_data.csv", header=TRUE, sep = ";")
aggregatedData <- aggregatedData[2:9]

numberOfSubjects <- 20
numberOfDatasets <- 2

# ==================================================
# Round 1
# ==================================================

# ==================================================
# Calculate timings for hypotheses - 
# ==================================================

	#interfaceChars <- c("STZ","KNAVE")
	hypothesesNames <- c("H1.1","H1.2","H2.1", "H2.2")
	taskNrH1 <- c(1,2,3)
	taskNrH2 <- c(4,5,6)
	taskNrH3 <- c(7,8,9)
	taskNrH4 <- c(10,11,12)
	taskNrHypotheses <- list(taskNrH1, taskNrH2, taskNrH3, taskNrH4)
	interfacesH1 <- c("STZ","KNAVE")
	interfacesH2 <- c("STZ","KNAVE")
	interfacesH3 <- c("STZ","KNAVE")
	interfacesH4 <- c("STZ","KNAVE")
	interfacesHypotheses <- list(interfacesH1, interfacesH2, interfacesH3, interfacesH4)
	
	TimingsHypotheses <- data.frame(subject=numeric(0), hypothesis=character(0), interface=character(0), time_s=numeric(0))
	for (subjectNr in 1:numberOfSubjects) {
		for(hypothesesNr in 1:length(hypothesesNames)) {
			interfacesForHy <- interfacesHypotheses[[hypothesesNr]]
			numberOfTasksForHy <- length(taskNrHypotheses[[hypothesesNr]])
			tasksForHy <- taskNrHypotheses[[hypothesesNr]]
			for(interfaceNr in 1:length(interfacesForHy)) {		
				time_sum <- 0
				for(i in 1:numberOfTasksForHy) {
					
					time <- log(aggregatedData[aggregatedData[1]==subjectNr & aggregatedData[6]==interfacesForHy[interfaceNr] & aggregatedData[2]==tasksForHy[i] & aggregatedData[8]==1,3])
					#time <- aggregatedData[aggregatedData[1]==subjectNr & aggregatedData[6]==interfacesForHy[interfaceNr] & aggregatedData[2]==tasksForHy[i] & aggregatedData[8]==1,3]
					if (length(time)>1){
						time_sum <- time_sum + time[1] + time[2]
					}
				} 
				if (time_sum>0) {
					TimingsHypotheses <- rbind(TimingsHypotheses, data.frame(subject=subjectNr, hypothesis=hypothesesNames[hypothesesNr], interface=interfacesForHy[interfaceNr], time_s=time_sum))
				}
			}
		}
	}
	

# ==================================================
# Summary Statistics
# ==================================================
sumstats_hypotheses_timings <- data.frame(hypothesis=character(0), interface=character(0), MIN=numeric(0), Q1=numeric(0), MEDIAN=numeric(0), MEAN=numeric(0), Q3=numeric(0), MAX=numeric(0), SD=numeric(0))

for(hypothesesNr in 1:length(hypothesesNames)) {
	interfacesForHy <- interfacesHypotheses[[hypothesesNr]]
	for(interfaceNr in 1:length(interfacesForHy)) {		
		times <- TimingsHypotheses[TimingsHypotheses[3]==interfacesForHy[interfaceNr] & TimingsHypotheses[2]==hypothesesNames[hypothesesNr],4]
		sumstats_hypotheses_timings <- rbind(sumstats_hypotheses_timings, data.frame(hypothesis=hypothesesNames[hypothesesNr], interface=interfacesForHy[interfaceNr], MIN=min(times), Q1=quantile(times,0.25), MEDIAN=median(times), MEAN=mean(times), Q3=quantile(times,0.75), MAX=max(times), SD=sd(times)))
	}
}

write.csv(sumstats_hypotheses_timings,file="sumstats_hypotheses_timings_round_1.csv")

	
# ==================================================
# Boxplot Task Completion Times
# ==================================================
	pdf("timingBoxplots-hypotheses-row_round_1.pdf",width=10,height=4) 
	par(mfrow=c(1,4),mar=c(7,5,2,2),xpd=NA) 
	for (hypothesisNr in 1:4) {
		hypothesisString <- hypothesesNames[hypothesisNr]
		hypothesisDescription <- ""
		if (hypothesisNr == 1 | hypothesisNr == 3)
			hypothesisDescription <- paste(hypothesisString,"Lookup Tasks",sep=" ")
		if (hypothesisNr == 2 | hypothesisNr == 4)
			hypothesisDescription <- paste(hypothesisString,"Comparsion Tasks",sep=" ")	
		boxplot(time_s ~ interface, data = TimingsHypotheses, subset = hypothesis==hypothesisString, main= hypothesisDescription, ylab="time (s)", col = colors()[c(50,79,91)], boxwex=0.5, bty="n", cex.lab=1.4, cex.axis=1.0, cex.main=1.6, names = c("STZ", "KNAVE"), whisklty="solid")
		#ylim=c(100,800)
		#legend("bottomleft", c("Juxtaposition (A)", "Superimposition (B)", "Indexing (C)"), fill = colors()[c(50,79,91)], cex=0.8)
	}
	#legend(-13, 0, c("Li+J", "Lo+S", "I"), fill = colors()[c(50,79,91)], bty="n", cex=1.4, hor=TRUE)
	dev.off()
	
# ==================================================
# Test for normal distribution
# ==================================================
	shapirowilk_H_Round_1 <- data.frame(Hypothesis="Hx",Interface="X",SW=0.0)
	interfaceChars <- c("STZ","KNAVE")
	for (hypothesisNr in 1:4) {
		#hypothesisString <- paste("H",hypothesisNr,sep="")
		hypothesisString <- hypothesesNames[hypothesisNr]
		TimingsH <- TimingsHypotheses[TimingsHypotheses[2]==hypothesisString,1:4]
		for(interfaceNr in 1:2) {
			times <- TimingsH[TimingsH[3]==interfaceChars[interfaceNr],4]
			if(length(times)>0) {
				sw <- shapiro.test(times)$p.value
				shapirowilk_H_Round_1 <- rbind(shapirowilk_H_Round_1, data.frame(Hypothesis=hypothesisString,Interface=interfaceChars[interfaceNr],SW=sw))
			}
		}	
	}
	write.csv(shapirowilk_H_Round_1,file="shapirowilk_hypotheses_round_1.csv")
	
# ==================================================
# Testing for equal variance (F-Test)
# ==================================================

	equal_var <- data.frame(Hypothesis="Hx",SW=0.0)
	
	# H1.1 
	sw <- var.test(TimingsHypotheses[TimingsHypotheses[2]=="H1.1" & TimingsHypotheses[3]=="STZ", "time_s"], TimingsHypotheses[TimingsHypotheses[2]=="H1.1" & TimingsHypotheses[3]=="KNAVE", "time_s"])$p.value
	
	equal_var <- rbind(equal_var, data.frame(Hypothesis="H1.1",SW=sw))
	
	# H1.2 
	sw <- var.test(TimingsHypotheses[TimingsHypotheses[2]=="H1.2" & TimingsHypotheses[3]=="STZ", "time_s"], TimingsHypotheses[TimingsHypotheses[2]=="H1.2" & TimingsHypotheses[3]=="KNAVE", "time_s"])$p.value
	
	equal_var <- rbind(equal_var, data.frame(Hypothesis="H1.2",SW=sw))
	
	# H2.1
	sw <- var.test(TimingsHypotheses[TimingsHypotheses[2]=="H2.1" & TimingsHypotheses[3]=="STZ", "time_s"], TimingsHypotheses[TimingsHypotheses[2]=="H2.1" & TimingsHypotheses[3]=="KNAVE", "time_s"])$p.value
	
	equal_var <- rbind(equal_var, data.frame(Hypothesis="H2.1",SW=sw))
	
	# H2.2
	sw <- var.test(TimingsHypotheses[TimingsHypotheses[2]=="H2.2" & TimingsHypotheses[3]=="STZ", "time_s"], TimingsHypotheses[TimingsHypotheses[2]=="H2.2" & TimingsHypotheses[3]=="KNAVE", "time_s"])$p.value
	
	equal_var <- rbind(equal_var, data.frame(Hypothesis="H2.2",SW=sw))
	
	write.csv(equal_var,file="hypothesis_equal_variance_round_1.csv")
	
# ==================================================
# T-Test (not paired, one sided)
# ==================================================

library(MBESS)

t_test <- data.frame(Hypothesis="Hx",SW=0.0, D=0.0)

# H1.1 
sw <- t.test(TimingsHypotheses[TimingsHypotheses[2]=="H1.1" & TimingsHypotheses[3]=="STZ", "time_s"], TimingsHypotheses[TimingsHypotheses[2]=="H1.1" & TimingsHypotheses[3]=="KNAVE", "time_s"], paired = F, alternative="less")$p.value

# effect size
d <- abs(smd(TimingsHypotheses[TimingsHypotheses[2]=="H1.1" & TimingsHypotheses[3]=="STZ", "time_s"], TimingsHypotheses[TimingsHypotheses[2]=="H1.1" & TimingsHypotheses[3]=="KNAVE", "time_s"]))

t_test <- rbind(t_test, data.frame(Hypothesis="H1.1",SW=sw, D=d))

# H1.2 
sw <- t.test(TimingsHypotheses[TimingsHypotheses[2]=="H1.2" & TimingsHypotheses[3]=="STZ", "time_s"], TimingsHypotheses[TimingsHypotheses[2]=="H1.2" & TimingsHypotheses[3]=="KNAVE", "time_s"], paired = F, alternative="less")$p.value

# effect size
d <- abs(smd(TimingsHypotheses[TimingsHypotheses[2]=="H1.1" & TimingsHypotheses[3]=="STZ", "time_s"], TimingsHypotheses[TimingsHypotheses[2]=="H1.2" & TimingsHypotheses[3]=="KNAVE", "time_s"]))


t_test <- rbind(t_test, data.frame(Hypothesis="H1.2",SW=sw, D=d))

# H2.1 
sw <- t.test(TimingsHypotheses[TimingsHypotheses[2]=="H2.1" & TimingsHypotheses[3]=="STZ", "time_s"], TimingsHypotheses[TimingsHypotheses[2]=="H2.1" & TimingsHypotheses[3]=="KNAVE", "time_s"], paired = F, alternative="less")$p.value

# effect size
d <- abs(smd(TimingsHypotheses[TimingsHypotheses[2]=="H2.1" & TimingsHypotheses[3]=="STZ", "time_s"], TimingsHypotheses[TimingsHypotheses[2]=="H2.1" & TimingsHypotheses[3]=="KNAVE", "time_s"]))

t_test <- rbind(t_test, data.frame(Hypothesis="H2.1",SW=sw, D=d))

# H2.2
sw <- t.test(TimingsHypotheses[TimingsHypotheses[2]=="H2.2" & TimingsHypotheses[3]=="STZ", "time_s"], TimingsHypotheses[TimingsHypotheses[2]=="H2.2" & TimingsHypotheses[3]=="KNAVE", "time_s"], paired = F, alternative="less")$p.value

d <- abs(smd(TimingsHypotheses[TimingsHypotheses[2]=="H2.2" & TimingsHypotheses[3]=="STZ", "time_s"], TimingsHypotheses[TimingsHypotheses[2]=="H2.2" & TimingsHypotheses[3]=="KNAVE", "time_s"]))

t_test <- rbind(t_test, data.frame(Hypothesis="H2.2",SW=sw, D=d))

write.csv(t_test,file="hypothesis_t_test_round_1.csv")

# ==================================================
# Round 2
# ==================================================

# ==================================================
# Calculate timings for hypotheses - 
# ==================================================

	
	TimingsHypothesesRound2 <- data.frame(subject=numeric(0), hypothesis=character(0), interface=character(0), time_s=numeric(0))
	for (subjectNr in 1:numberOfSubjects) {
		for(hypothesesNr in 1:length(hypothesesNames)) {
			interfacesForHy <- interfacesHypotheses[[hypothesesNr]]
			numberOfTasksForHy <- length(taskNrHypotheses[[hypothesesNr]])
			tasksForHy <- taskNrHypotheses[[hypothesesNr]]
			for(interfaceNr in 1:length(interfacesForHy)) {		
				time_sum <- 0
				for(i in 1:numberOfTasksForHy) {
					
					
					time <- log(aggregatedData[aggregatedData[1]==subjectNr & aggregatedData[6]==interfacesForHy[interfaceNr] & aggregatedData[2]==tasksForHy[i] & aggregatedData[8]==2,3])
					#time <- aggregatedData[aggregatedData[1]==subjectNr & aggregatedData[6]==interfacesForHy[interfaceNr] & aggregatedData[2]==tasksForHy[i]& aggregatedData[8] ==2,3]
					if (length(time)>1){
						time_sum <- time_sum + time[1] + time[2]
					}
				} 
				if (time_sum>0) {
					TimingsHypothesesRound2 <- rbind(TimingsHypothesesRound2, data.frame(subject=subjectNr, hypothesis=hypothesesNames[hypothesesNr], interface=interfacesForHy[interfaceNr], time_s=time_sum))
				}
			}
		}
	}
	
	# change the order of the factor
	TimingsHypothesesRound2$interface = factor(TimingsHypothesesRound2$interface,c("STZ","KNAVE"))

	
# ==================================================
# Summary Statistics
# ==================================================
sumstats_hypotheses_timings <- data.frame(hypothesis=character(0), interface=character(0), MIN=numeric(0), Q1=numeric(0), MEDIAN=numeric(0), MEAN=numeric(0), Q3=numeric(0), MAX=numeric(0), SD=numeric(0))

for(hypothesesNr in 1:length(hypothesesNames)) {
	interfacesForHy <- interfacesHypotheses[[hypothesesNr]]
	for(interfaceNr in 1:length(interfacesForHy)) {		
		times <- TimingsHypothesesRound2[TimingsHypothesesRound2[3]==interfacesForHy[interfaceNr] & TimingsHypothesesRound2[2]==hypothesesNames[hypothesesNr],4]
		sumstats_hypotheses_timings <- rbind(sumstats_hypotheses_timings, data.frame(hypothesis=hypothesesNames[hypothesesNr], interface=interfacesForHy[interfaceNr], MIN=min(times), Q1=quantile(times,0.25), MEDIAN=median(times), MEAN=mean(times), Q3=quantile(times,0.75), MAX=max(times), SD=sd(times)))
	}
}

write.csv(sumstats_hypotheses_timings,file="sumstats_hypotheses_timings_round_2.csv")

	
# ==================================================
# Boxplot Task Completion Times
# ==================================================
	pdf("timingBoxplots-hypotheses-row_round_2.pdf",width=10,height=4) 
	par(mfrow=c(1,4),mar=c(7,5,2,2),xpd=NA) 
	for (hypothesisNr in 1:4) {
		hypothesisString <- hypothesesNames[hypothesisNr]
		hypothesisDescription <- ""
		if (hypothesisNr == 1 | hypothesisNr == 3)
			hypothesisDescription <- paste(hypothesisString,"Lookup Tasks",sep=" ")
		if (hypothesisNr == 2 | hypothesisNr == 4)
			hypothesisDescription <- paste(hypothesisString,"Comparsion Tasks",sep=" ")	
		#hypothesisString <- paste("H",hypothesisNr,sep="")
		boxplot(time_s ~ interface, data = TimingsHypothesesRound2, subset = hypothesis==hypothesisString, main=hypothesisDescription, ylab="time (s)", col = colors()[c(50,79,91)], boxwex=0.5, bty="n", cex.lab=1.4, cex.axis=1.0, cex.main=1.6, names = c("STZ", "KNAVE"), whisklty="solid")
		#ylim=c(100,800)
		#legend("bottomleft", c("Juxtaposition (A)", "Superimposition (B)", "Indexing (C)"), fill = colors()[c(50,79,91)], cex=0.8)
	}
	#legend(-13, 0, c("Li+J", "Lo+S", "I"), fill = colors()[c(50,79,91)], bty="n", cex=1.4, hor=TRUE)
	dev.off()
	
# ==================================================
# Test for normal distribution
# ==================================================
	shapirowilk_H_Round_2 <- data.frame(Hypothesis="Hx",Interface="X",SW=0.0)
	interfaceChars <- c("STZ","KNAVE")
	for (hypothesisNr in 1:4) {
		#hypothesisString <- paste("H",hypothesisNr,sep="")
		hypothesisString <- hypothesesNames[hypothesisNr]
		TimingsH <- TimingsHypothesesRound2[TimingsHypothesesRound2[2]==hypothesisString,1:4]
		for(interfaceNr in 1:2) {
			times <- TimingsH[TimingsH[3]==interfaceChars[interfaceNr],4]
			if(length(times)>0) {
				sw <- shapiro.test(times)$p.value
				shapirowilk_H_Round_2 <- rbind(shapirowilk_H_Round_2, data.frame(Hypothesis=hypothesisString,Interface=interfaceChars[interfaceNr],SW=sw))
			}
		}	
	}
	write.csv(shapirowilk_H_Round_2,file="shapirowilk_hypotheses_round_2.csv")
	
# ==================================================
# Testing for equal variance (F-Test)
# ==================================================

	equal_var <- data.frame(Hypothesis="Hx",SW=0.0)
	
	# H1.1 
	sw <- var.test(TimingsHypothesesRound2[TimingsHypothesesRound2[2]=="H1.1" & TimingsHypothesesRound2[3]=="STZ", "time_s"], TimingsHypothesesRound2[TimingsHypothesesRound2[2]=="H1.1" & TimingsHypothesesRound2[3]=="KNAVE", "time_s"])$p.value
	
	equal_var <- rbind(equal_var, data.frame(Hypothesis="H1.1",SW=sw))
	
	# H1.2 
	sw <- var.test(TimingsHypothesesRound2[TimingsHypothesesRound2[2]=="H1.2" & TimingsHypothesesRound2[3]=="STZ", "time_s"], TimingsHypothesesRound2[TimingsHypothesesRound2[2]=="H1.2" & TimingsHypothesesRound2[3]=="KNAVE", "time_s"])$p.value
	
	equal_var <- rbind(equal_var, data.frame(Hypothesis="H1.2",SW=sw))
	
	# H2.1
	sw <- var.test(TimingsHypothesesRound2[TimingsHypothesesRound2[2]=="H2.1" & TimingsHypothesesRound2[3]=="STZ", "time_s"], TimingsHypothesesRound2[TimingsHypothesesRound2[2]=="H2.1" & TimingsHypothesesRound2[3]=="KNAVE", "time_s"])$p.value
	
	equal_var <- rbind(equal_var, data.frame(Hypothesis="H2.1",SW=sw))
	
	# H2.2
	sw <- var.test(TimingsHypothesesRound2[TimingsHypothesesRound2[2]=="H2.2" & TimingsHypothesesRound2[3]=="STZ", "time_s"], TimingsHypothesesRound2[TimingsHypothesesRound2[2]=="H2.2" & TimingsHypothesesRound2[3]=="KNAVE", "time_s"])$p.value
	
	equal_var <- rbind(equal_var, data.frame(Hypothesis="H2.2",SW=sw))
	
	write.csv(equal_var,file="hypothesis_equal_variance_round_2.csv")
	
# ==================================================
# T-Test (not paired, one sided)
# ==================================================

t_test <- data.frame(Hypothesis="Hx",SW=0.0, D=0.0)

# H1.1 
sw <- t.test(TimingsHypothesesRound2[TimingsHypothesesRound2[2]=="H1.1" & TimingsHypothesesRound2[3]=="STZ", "time_s"], TimingsHypothesesRound2[TimingsHypothesesRound2[2]=="H1.1" & TimingsHypothesesRound2[3]=="KNAVE", "time_s"], paired = F, alternative="less")$p.value

# effect size
d <- abs(smd(TimingsHypothesesRound2[TimingsHypothesesRound2[2]=="H1.1" & TimingsHypothesesRound2[3]=="STZ", "time_s"], TimingsHypothesesRound2[TimingsHypothesesRound2[2]=="H1.1" & TimingsHypothesesRound2[3]=="KNAVE", "time_s"]))


t_test <- rbind(t_test, data.frame(Hypothesis="H1.1",SW=sw, D=d))

# H1.2 
sw <- t.test(TimingsHypothesesRound2[TimingsHypothesesRound2[2]=="H1.2" & TimingsHypothesesRound2[3]=="STZ", "time_s"], TimingsHypothesesRound2[TimingsHypothesesRound2[2]=="H1.2" & TimingsHypothesesRound2[3]=="KNAVE", "time_s"], paired = F, alternative="less")$p.value

# effect size
d <- abs(smd(TimingsHypothesesRound2[TimingsHypothesesRound2[2]=="H1.2" & TimingsHypothesesRound2[3]=="STZ", "time_s"], TimingsHypothesesRound2[TimingsHypothesesRound2[2]=="H1.2" & TimingsHypothesesRound2[3]=="KNAVE", "time_s"]))


t_test <- rbind(t_test, data.frame(Hypothesis="H1.2",SW=sw, D=d))

# H2.1 
sw <- t.test(TimingsHypothesesRound2[TimingsHypothesesRound2[2]=="H2.1" & TimingsHypothesesRound2[3]=="STZ", "time_s"], TimingsHypothesesRound2[TimingsHypothesesRound2[2]=="H2.1" & TimingsHypothesesRound2[3]=="KNAVE", "time_s"], paired = F, alternative="less")$p.value

# effect size
d <- abs(smd(TimingsHypothesesRound2[TimingsHypothesesRound2[2]=="H2.1" & TimingsHypothesesRound2[3]=="STZ", "time_s"], TimingsHypothesesRound2[TimingsHypothesesRound2[2]=="H2.1" & TimingsHypothesesRound2[3]=="KNAVE", "time_s"]))


t_test <- rbind(t_test, data.frame(Hypothesis="H2.1",SW=sw, D=d))

# H2.2
sw <- t.test(TimingsHypothesesRound2[TimingsHypothesesRound2[2]=="H2.2" & TimingsHypothesesRound2[3]=="STZ", "time_s"], TimingsHypothesesRound2[TimingsHypothesesRound2[2]=="H2.2" & TimingsHypothesesRound2[3]=="KNAVE", "time_s"], paired = F, alternative="less")$p.value

# effect size
d <- abs(smd(TimingsHypothesesRound2[TimingsHypothesesRound2[2]=="H2.2" & TimingsHypothesesRound2[3]=="STZ", "time_s"], TimingsHypothesesRound2[TimingsHypothesesRound2[2]=="H2.2" & TimingsHypothesesRound2[3]=="KNAVE", "time_s"]))


t_test <- rbind(t_test, data.frame(Hypothesis="H2.2",SW=sw, D=d))

write.csv(t_test,file="hypothesis_t_test_round_2.csv")



